@@ -20,21 +20,14 @@
  *             William Jon McCann
  */
 
-#ifndef __GNOME_LANGUAGES_H
-#define __GNOME_LANGUAGES_H
+#pragma once
 
 #include <glib.h>
 
-G_BEGIN_DECLS
-
-char *gnome_get_language_from_locale (const char *locale,
-                                      const char *translation);
-gboolean gnome_parse_locale (const char *locale,
-                             char **language_codep,
-                             char **country_codep,
-                             char **codesetp,
-                             char **modifierp);
-
-G_END_DECLS
-
-#endif /* __GNOME_LANGUAGES_H */
+char      *gnome_get_language_from_locale (const char *locale,
+                                           const char *translation);
+gboolean   gnome_parse_locale             (const char *locale,
+                                           char      **language_codep,
+                                           char      **country_codep,
+                                           char      **codesetp,
+                                           char      **modifierp);
