@@ -1,4 +1,4 @@
-/* Copyright (C) Gabor Karsay 2020 <gabor.karsay@gmx.at>
+/* Copyright 2020 Gabor Karsay <gabor.karsay@gmx.at>
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as published
@@ -14,17 +14,10 @@
  * with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef GST_HELPERS_H
-#define GST_HELPERS_H
+#pragma once
 
 #include <gst/gst.h>
 
-G_BEGIN_DECLS
-
-GstElement *_pt_make_element (gchar *factoryname,
-                              gchar *name,
+GstElement *_pt_make_element (gchar   *factoryname,
+                              gchar   *name,
                               GError **error);
-
-G_END_DECLS
-
-#endif
