@@ -36,49 +36,13 @@
  * Author: David Huggins-Daines <dhuggins@cs.cmu.edu>
  */
 
-#ifndef __GST_PARLASPHINX_H__
-#define __GST_PARLASPHINX_H__
+#pragma once
 
 #include <gst/gst.h>
 #include <pocketsphinx.h>
 
-G_BEGIN_DECLS
-
-#define GST_TYPE_PARLASPHINX \
-  (gst_parlasphinx_get_type ())
-#define GST_PARLASPHINX(obj) \
-  (G_TYPE_CHECK_INSTANCE_CAST ((obj), GST_TYPE_PARLASPHINX, GstParlaSphinx))
-#define GST_PARLASPHINX_CLASS(klass) \
-  (G_TYPE_CHECK_CLASS_CAST ((klass), GST_TYPE_PARLASPHINX, GstParlaSphinxClass))
-#define GST_IS_PARLASPHINX(obj) \
-  (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GST_TYPE_PARLASPHINX))
-#define GST_IS_PARLASPHINX_CLASS(klass) \
-  (G_TYPE_CHECK_CLASS_TYPE ((klass), GST_TYPE_PARLASPHINX))
-
-typedef struct _GstParlaSphinx GstParlaSphinx;
-typedef struct _GstParlaSphinxClass GstParlaSphinxClass;
-
-struct _GstParlaSphinx
-{
-  GstElement element;
-
-  GstPad *sinkpad, *srcpad;
-
-  ps_decoder_t *ps;
-  cmd_ln_t *config;
-
-  gchar *latdir; /**< Output directory for word lattices. */
-
-  gboolean speech_started;
-  gboolean listening_started;
-  gint uttno;
-
-  GstClockTime last_result_time; /**< Timestamp of last partial result. */
-  char *last_result;             /**< String of last partial result. */
-
-  GstSegment segment;
-  gboolean eos;
-};
+#define GST_TYPE_PARLASPHINX (gst_parlasphinx_get_type ())
+G_DECLARE_FINAL_TYPE (GstParlasphinx, gst_parlasphinx, GST, PARLASPHINX, GstElement)
 
 struct _GstParlaSphinxClass
 {
@@ -88,8 +52,6 @@ struct _GstParlaSphinxClass
   void (*result) (GstElement *element, const gchar *hyp_str);
 };
 
-GType gst_parlasphinx_get_type (void);
-
 /*
  * Boxing of decoder.
  */
@@ -97,7 +59,3 @@ GType gst_parlasphinx_get_type (void);
 GType ps_decoder_get_type (void);
 
 gboolean gst_parlasphinx_register (void);
-
-G_END_DECLS
-
-#endif /* __GST_PARLASPHINX_H__ */
