@@ -1,4 +1,4 @@
-/* Copyright (C) Gabor Karsay 2020 <gabor.karsay@gmx.at>
+/* Copyright 2020 Gabor Karsay <gabor.karsay@gmx.at>
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as published
@@ -30,20 +30,35 @@
  *
  */
 
-#include "config.h"
 #define GETTEXT_PACKAGE GETTEXT_LIB
-#include <glib/gi18n-lib.h>
-#include <gio/gio.h>
-#include <gst/gst.h>
-#include "pt-config.h"
-#include "gst-helpers.h"
+
+#include "config.h"
+
 #include "gstptaudioasrbin.h"
 
+#include "gst-helpers.h"
+#include "pt-config.h"
+
+#include <gio/gio.h>
+#include <glib/gi18n-lib.h>
+#include <gst/gst.h>
+
 GST_DEBUG_CATEGORY_STATIC (gst_pt_audio_asr_bin_debug);
 #define GST_CAT_DEFAULT gst_pt_audio_asr_bin_debug
 
 #define parent_class gst_pt_audio_asr_bin_parent_class
 
+struct _GstPtAudioAsrBin
+{
+  GstBin parent;
+
+  PtConfig   *config;
+  GstElement *asr_plugin;
+  GstElement *audioresample;
+  GstElement *fakesink;
+  gboolean    is_configured;
+};
+
 G_DEFINE_TYPE (GstPtAudioAsrBin, gst_pt_audio_asr_bin, GST_TYPE_BIN);
 
 gboolean
@@ -54,8 +69,8 @@ gst_pt_audio_asr_bin_is_configured (GstPtAudioAsrBin *self)
 
 gboolean
 gst_pt_audio_asr_bin_configure_asr_finish (GstPtAudioAsrBin *self,
-                                           GAsyncResult *result,
-                                           GError **error)
+                                           GAsyncResult     *result,
+                                           GError          **error)
 {
   g_return_val_if_fail (g_task_is_valid (result, self), FALSE);
 
@@ -66,9 +81,9 @@ static void
 configure_plugin (GTask *task)
 {
   GstPtAudioAsrBin *self;
-  gchar *plugin;
-  gboolean success;
-  GError *error = NULL;
+  gchar            *plugin;
+  gboolean          success;
+  GError           *error = NULL;
 
   self = g_task_get_source_object (task);
   plugin = pt_config_get_plugin (self->config);
@@ -127,7 +142,7 @@ configure_plugin (GTask *task)
 static void
 flush_plugin (GstPtAudioAsrBin *self)
 {
-  GstPad *sinkpad;
+  GstPad  *sinkpad;
   gboolean success;
 
   GST_DEBUG_OBJECT (self, "flushing ASR plugin");
@@ -139,11 +154,11 @@ flush_plugin (GstPtAudioAsrBin *self)
 }
 
 static GstPadProbeReturn
-pad_probe_cb (GstPad *pad,
+pad_probe_cb (GstPad          *pad,
               GstPadProbeInfo *info,
-              gpointer user_data)
+              gpointer         user_data)
 {
-  GTask *task = G_TASK (user_data);
+  GTask            *task = G_TASK (user_data);
   GstPtAudioAsrBin *self;
 
   self = g_task_get_source_object (task);
@@ -167,17 +182,17 @@ pad_probe_cb (GstPad *pad,
 }
 
 void
-gst_pt_audio_asr_bin_configure_asr_async (GstPtAudioAsrBin *self,
-                                          PtConfig *config,
-                                          GCancellable *cancellable,
+gst_pt_audio_asr_bin_configure_asr_async (GstPtAudioAsrBin   *self,
+                                          PtConfig           *config,
+                                          GCancellable       *cancellable,
                                           GAsyncReadyCallback callback,
-                                          gpointer user_data)
+                                          gpointer            user_data)
 {
   GST_DEBUG_OBJECT (self, "configuring asr");
 
-  GTask *task;
-  GstPad *blockpad;
-  gulong probe_id;
+  GTask   *task;
+  GstPad  *blockpad;
+  gulong   probe_id;
   GstState debug_state;
 
   task = g_task_new (self, cancellable, callback, user_data);
@@ -231,31 +246,31 @@ gst_pt_audio_asr_bin_finalize (GObject *object)
 }
 
 static void
-gst_pt_audio_asr_bin_init (GstPtAudioAsrBin *bin)
+gst_pt_audio_asr_bin_init (GstPtAudioAsrBin *self)
 {
   GstElement *audioconvert;
-  GstPad *audioconvert_sink;
+  GstPad     *audioconvert_sink;
 
   audioconvert = _pt_make_element ("audioconvert",
                                    "audioconvert", NULL);
-  bin->audioresample = _pt_make_element ("audioresample",
-                                         "audioresample", NULL);
-  bin->fakesink = _pt_make_element ("fakesink",
-                                    "fakesink", NULL);
+  self->audioresample = _pt_make_element ("audioresample",
+                                          "audioresample", NULL);
+  self->fakesink = _pt_make_element ("fakesink",
+                                     "fakesink", NULL);
 
   /* create audio output */
-  gst_bin_add_many (GST_BIN (bin), audioconvert, bin->audioresample,
-                    bin->fakesink, NULL);
-  gst_element_link_many (audioconvert, bin->audioresample, NULL);
+  gst_bin_add_many (GST_BIN (self), audioconvert, self->audioresample,
+                    self->fakesink, NULL);
+  gst_element_link_many (audioconvert, self->audioresample, NULL);
 
   /* create ghost pad for audiosink */
   audioconvert_sink = gst_element_get_static_pad (audioconvert, "sink");
-  gst_element_add_pad (GST_ELEMENT (bin),
+  gst_element_add_pad (GST_ELEMENT (self),
                        gst_ghost_pad_new ("sink", audioconvert_sink));
   gst_object_unref (GST_OBJECT (audioconvert_sink));
 
-  bin->asr_plugin = NULL;
-  bin->is_configured = FALSE;
+  self->asr_plugin = NULL;
+  self->is_configured = FALSE;
 }
 
 static void
@@ -299,5 +314,5 @@ gst_pt_audio_asr_bin_register (void)
       "GPL",
       "libparlatype",
       "Parlatype",
-      "https://www.parlatype.org/");
+      PACKAGE_URL);
 }
