@@ -1,4 +1,4 @@
-/* Copyright (C) Gabor Karsay 2020 <gabor.karsay@gmx.at>
+/* Copyright 2020 Gabor Karsay <gabor.karsay@gmx.at>
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as published
@@ -40,13 +40,17 @@ Note 1: It doesn’t work if play_audio_play_bin or pt_audio_asr_bin are added t
 
 */
 
-#include "config.h"
 #define GETTEXT_PACKAGE GETTEXT_LIB
+
+#include "config.h"
+
+#include "gstptaudiobin.h"
+
 #include "gst-helpers.h"
 #include "gstptaudioasrbin.h"
-#include "gstptaudiobin.h"
 #include "gstptaudioplaybin.h"
 #include "pt-config.h"
+
 #include <gio/gio.h>
 #include <glib/gi18n-lib.h>
 #include <gst/gst.h>
@@ -56,17 +60,34 @@ GST_DEBUG_CATEGORY_STATIC (gst_pt_audio_bin_debug);
 
 #define parent_class gst_pt_audio_bin_parent_class
 
+struct _GstPtAudioBin
+{
+  GstBin     parent;
+  PtModeType mode;
+  PtModeType pending;
+  gulong     probe_id;
+
+  GstElement *play_bin;
+  GstElement *asr_bin;
+  GstPad     *id_sink;
+  GstPad     *id_src;
+
+  /* properties */
+  gboolean player;
+  gboolean asr;
+};
+
 G_DEFINE_TYPE (GstPtAudioBin, gst_pt_audio_bin, GST_TYPE_BIN);
 
 static GstPadProbeReturn
-change_mode_cb (GstPad *pad,
+change_mode_cb (GstPad          *pad,
                 GstPadProbeInfo *info,
-                gpointer user_data)
+                gpointer         user_data)
 {
-  GstPtAudioBin *self = GST_PT_AUDIO_BIN (user_data);
-  GstElement *old_child, *new_child;
-  GstPad *sinkpad;
-  GstObject *parent;
+  GstPtAudioBin   *self = GST_PT_AUDIO_BIN (user_data);
+  GstElement      *old_child, *new_child;
+  GstPad          *sinkpad;
+  GstObject       *parent;
   GstPadLinkReturn r;
 
   gst_pad_remove_probe (pad, GST_PAD_PROBE_INFO_ID (info));
@@ -146,13 +167,13 @@ change_mode_cb (GstPad *pad,
 typedef struct
 {
   GAsyncResult *res;
-  GMainLoop *loop;
+  GMainLoop    *loop;
 } SyncData;
 
 static void
 quit_loop_cb (GstPtAudioBin *self,
-              GAsyncResult *res,
-              gpointer user_data)
+              GAsyncResult  *res,
+              gpointer       user_data)
 {
   SyncData *data = user_data;
   data->res = g_object_ref (res);
@@ -161,15 +182,15 @@ quit_loop_cb (GstPtAudioBin *self,
 
 gboolean
 gst_pt_audio_bin_configure_asr (GstPtAudioBin *self,
-                                PtConfig *config,
-                                GError **error)
+                                PtConfig      *config,
+                                GError       **error)
 {
   g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
 
   GstPtAudioAsrBin *bin;
-  SyncData data;
-  GMainContext *context;
-  gboolean result;
+  SyncData          data;
+  GMainContext     *context;
+  gboolean          result;
 
   bin = GST_PT_AUDIO_ASR_BIN (self->asr_bin);
   context = g_main_context_new ();
@@ -226,7 +247,7 @@ gst_pt_audio_bin_set_mode (GstPtAudioBin *self,
   self->pending = new;
 
   if (self->pending == PT_MODE_ASR &&
-      !GST_PT_AUDIO_ASR_BIN (self->asr_bin)->is_configured)
+      !gst_pt_audio_asr_bin_is_configured (GST_PT_AUDIO_ASR_BIN (self->asr_bin)))
     return;
 
   GST_DEBUG_OBJECT (self, "blocking pad for mode switch from %d to %d",
@@ -290,7 +311,7 @@ static void
 gst_pt_audio_bin_init (GstPtAudioBin *self)
 {
   GstElement *identity;
-  GstPad *play_sink;
+  GstPad     *play_sink;
 
   gst_pt_audio_play_bin_register ();
   gst_pt_audio_asr_bin_register ();
@@ -355,5 +376,5 @@ gst_pt_audio_bin_register (void)
       "GPL",
       "libparlatype",
       "Parlatype",
-      "https://www.parlatype.org/");
+      PACKAGE_URL);
 }
