@@ -1,4 +1,4 @@
-/* Copyright (C) Gabor Karsay 2020 <gabor.karsay@gmx.at>
+/* Copyright 2020 Gabor Karsay <gabor.karsay@gmx.at>
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as published
@@ -31,30 +31,38 @@
  * audiosink is chosen at runtime.
  */
 
-#include "config.h"
 #define GETTEXT_PACKAGE GETTEXT_LIB
+
+#include "config.h"
+
+#include "gstptaudioplaybin.h"
+
+#include "gst-helpers.h"
+
 #include <gio/gio.h>
 #include <glib/gi18n-lib.h>
-#include <gst/gst.h>
 #include <gst/audio/streamvolume.h>
-#include "gst-helpers.h"
-#include "gstptaudioplaybin.h"
+#include <gst/gst.h>
 
 GST_DEBUG_CATEGORY_STATIC (gst_pt_audio_play_bin_debug);
 #define GST_CAT_DEFAULT gst_pt_audio_play_bin_debug
 
 #define parent_class gst_pt_audio_play_bin_parent_class
 
+struct _GstPtAudioPlayBin
+{
+  GstBin parent;
+};
+
 G_DEFINE_TYPE (GstPtAudioPlayBin, gst_pt_audio_play_bin, GST_TYPE_BIN);
 
-#ifndef G_OS_WIN32
 static gboolean
 have_pulseaudio_server (void)
 {
   /* Adapted from Quod Libet ...quodlibet/player/gstbe/util.py:
    * If we have a pulsesink we can get the server presence through
    * setting the ready state */
-  GstElement *pulse;
+  GstElement          *pulse;
   GstStateChangeReturn state;
 
   pulse = gst_element_factory_make ("pulsesink", NULL);
@@ -66,31 +74,26 @@ have_pulseaudio_server (void)
   gst_object_unref (pulse);
   return (state != GST_STATE_CHANGE_FAILURE);
 }
-#endif
 
 static void
-gst_pt_audio_play_bin_init (GstPtAudioPlayBin *bin)
+gst_pt_audio_play_bin_init (GstPtAudioPlayBin *self)
 {
   /* Create gstreamer elements */
   GstElement *capsfilter;
   GstElement *audiosink;
-  gchar *sink;
+  gchar      *sink;
 
   capsfilter = _pt_make_element ("capsfilter", "audiofilter", NULL);
 
   /* Choose an audiosink ourselves instead of relying on autoaudiosink.
-   * It chose waveformsink on win32 (not a good choice) and it will be
-   * a fakesink until the first stream is loaded, so we can't query the
-   * sinks properties until then. */
+   * It will be a fakesink until the first stream is loaded, so we can't
+   * query the sinks properties until then. */
 
-#ifdef G_OS_WIN32
-  sink = "directsoundsink";
-#else
   if (have_pulseaudio_server ())
     sink = "pulsesink";
   else
     sink = "alsasink";
-#endif
+
   audiosink = gst_element_factory_make (sink, "audiosink");
   if (!audiosink)
     {
@@ -105,13 +108,13 @@ gst_pt_audio_play_bin_init (GstPtAudioPlayBin *bin)
                     "MESSAGE", "Audio sink implements stream volume: %s",
                     GST_IS_STREAM_VOLUME (audiosink) ? "yes" : "no");
 
-  gst_bin_add_many (GST_BIN (bin),
+  gst_bin_add_many (GST_BIN (self),
                     capsfilter, audiosink, NULL);
   gst_element_link_many (capsfilter, audiosink, NULL);
 
   /* create ghost pad for audiosink */
   GstPad *audiopad = gst_element_get_static_pad (capsfilter, "sink");
-  gst_element_add_pad (GST_ELEMENT (bin),
+  gst_element_add_pad (GST_ELEMENT (self),
                        gst_ghost_pad_new ("sink", audiopad));
   gst_object_unref (GST_OBJECT (audiopad));
 }
@@ -152,5 +155,5 @@ gst_pt_audio_play_bin_register (void)
       "GPL",
       "libparlatype",
       "Parlatype",
-      "https://www.parlatype.org/");
+      PACKAGE_URL);
 }
