@@ -1,4 +1,4 @@
-/* Copyright (C) Gabor Karsay 2021 <gabor.karsay@gmx.at>
+/* Copyright 2021 Gabor Karsay <gabor.karsay@gmx.at>
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as published
@@ -14,8 +14,7 @@
  * with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef PARLATYPE_H
-#define PARLATYPE_H
+#pragma once
 
 #define __PARLATYPE_H_INSIDE__
 
@@ -25,5 +24,3 @@
 #include "pt-waveviewer.h"
 
 #undef __PARLATYPE_H_INSIDE__
-
-#endif
