@@ -1,4 +1,4 @@
-/* Copyright (C) Gabor Karsay 2021 <gabor.karsay@gmx.at>
+/* Copyright 2021 Gabor Karsay <gabor.karsay@gmx.at>
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as published
@@ -14,41 +14,43 @@
  * with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "config.h"
-#include <gio/gio.h>
 #define GETTEXT_PACKAGE GETTEXT_LIB
-#include <glib/gi18n-lib.h>
-#include "contrib/gnome-languages.h"
+
+#include "config.h"
+
 #include "pt-config.h"
 
+#include "contrib/gnome-languages.h"
+
+#include <gio/gio.h>
+#include <glib/gi18n-lib.h>
+
+typedef struct _PtConfigPrivate PtConfigPrivate;
 struct _PtConfigPrivate
 {
-  gchar *path;
-  GFile *file;
+  gchar    *path;
+  GFile    *file;
   GKeyFile *keyfile;
-  gchar *name;
-  gchar *lang_name;
-  gchar *lang_code;
-  gchar *plugin;
-  gchar *base_folder;
-  gboolean is_valid;
-  gboolean is_installed;
+  gchar    *name;
+  gchar    *lang_name;
+  gchar    *lang_code;
+  gchar    *plugin;
+  gchar    *base_folder;
+  gboolean  is_valid;
+  gboolean  is_installed;
 };
 
 enum
 {
-  PROP_0,
-  PROP_FILE,
+  PROP_FILE = 1,
   PROP_IS_VALID,
   PROP_IS_INSTALLED,
   PROP_NAME,
   N_PROPERTIES
 };
 
-static GParamSpec *obj_properties[N_PROPERTIES] = {
-  NULL,
-};
-static gboolean pt_config_verify_install (PtConfig *config);
+static GParamSpec *obj_properties[N_PROPERTIES];
+static gboolean    pt_config_verify_install (PtConfig *self);
 
 G_DEFINE_TYPE_WITH_PRIVATE (PtConfig, pt_config, G_TYPE_OBJECT)
 
@@ -79,14 +81,15 @@ pt_error_quark (void)
 }
 
 static gboolean
-pt_config_save (PtConfig *config)
+pt_config_save (PtConfig *self)
 {
-  GError *error = NULL;
-  gboolean result;
+  PtConfigPrivate *priv = pt_config_get_instance_private (self);
+  GError          *error = NULL;
+  gboolean         result;
 
   result = g_key_file_save_to_file (
-      config->priv->keyfile,
-      config->priv->path,
+      priv->keyfile,
+      priv->path,
       &error);
 
   if (error)
@@ -100,22 +103,23 @@ pt_config_save (PtConfig *config)
 }
 
 static GValue
-pt_config_get_value (PtConfig *config,
-                     gchar *group,
-                     gchar *key,
-                     GType type)
+pt_config_get_value (PtConfig *self,
+                     gchar    *group,
+                     gchar    *key,
+                     GType     type)
 {
-  GError *error = NULL;
-  GValue result = G_VALUE_INIT;
+  PtConfigPrivate *priv = pt_config_get_instance_private (self);
+  GError          *error = NULL;
+  GValue           result = G_VALUE_INIT;
 
   if (g_strcmp0 (group, "Files") == 0)
     {
       g_value_init (&result, G_TYPE_STRING);
-      gchar *base = pt_config_get_base_folder (config);
-      gchar **pieces = g_key_file_get_string_list (config->priv->keyfile,
+      gchar  *base = pt_config_get_base_folder (self);
+      gchar **pieces = g_key_file_get_string_list (priv->keyfile,
                                                    "Files", key, NULL, &error);
-      gchar *relative = g_build_filenamev (pieces);
-      gchar *absolute = g_build_filename (base, relative, NULL);
+      gchar  *relative = g_build_filenamev (pieces);
+      gchar  *absolute = g_build_filename (base, relative, NULL);
       g_value_set_string (&result, absolute);
       g_free (absolute);
       g_free (relative);
@@ -127,7 +131,7 @@ pt_config_get_value (PtConfig *config,
         {
         case (G_TYPE_STRING):
           g_value_init (&result, G_TYPE_STRING);
-          gchar *string = g_key_file_get_string (config->priv->keyfile,
+          gchar *string = g_key_file_get_string (priv->keyfile,
                                                  "Parameters", key, &error);
           g_value_set_string (&result, string);
           g_free (string);
@@ -135,25 +139,25 @@ pt_config_get_value (PtConfig *config,
         case (G_TYPE_UINT):
         case (G_TYPE_INT):
           g_value_init (&result, G_TYPE_INT);
-          gint integer = g_key_file_get_integer (config->priv->keyfile,
+          gint integer = g_key_file_get_integer (priv->keyfile,
                                                  "Parameters", key, &error);
           g_value_set_int (&result, integer);
           break;
         case (G_TYPE_FLOAT):
           g_value_init (&result, G_TYPE_FLOAT);
-          gfloat floaty = g_key_file_get_double (config->priv->keyfile,
+          gfloat floaty = g_key_file_get_double (priv->keyfile,
                                                  "Parameters", key, &error);
           g_value_set_float (&result, floaty);
           break;
         case (G_TYPE_DOUBLE):
           g_value_init (&result, G_TYPE_DOUBLE);
-          gdouble doubly = g_key_file_get_double (config->priv->keyfile,
+          gdouble doubly = g_key_file_get_double (priv->keyfile,
                                                   "Parameters", key, &error);
           g_value_set_double (&result, doubly);
           break;
         case (G_TYPE_BOOLEAN):
           g_value_init (&result, G_TYPE_BOOLEAN);
-          gboolean boolean = g_key_file_get_boolean (config->priv->keyfile,
+          gboolean boolean = g_key_file_get_boolean (priv->keyfile,
                                                      "Parameters", key, &error);
           g_value_set_boolean (&result, boolean);
           break;
@@ -176,14 +180,15 @@ pt_config_get_value (PtConfig *config,
 }
 
 static gchar *
-pt_config_get_string (PtConfig *config,
-                      gchar *group,
-                      gchar *parameter)
+pt_config_get_string (PtConfig *self,
+                      gchar    *group,
+                      gchar    *parameter)
 {
-  GError *error = NULL;
-  gchar *result;
+  PtConfigPrivate *priv = pt_config_get_instance_private (self);
+  GError          *error = NULL;
+  gchar           *result;
 
-  result = g_key_file_get_string (config->priv->keyfile,
+  result = g_key_file_get_string (priv->keyfile,
                                   group, parameter, &error);
 
   if (error)
@@ -198,20 +203,21 @@ pt_config_get_string (PtConfig *config,
 }
 
 static gboolean
-pt_config_set_string (PtConfig *config,
-                      gchar *group,
-                      gchar *parameter,
-                      gchar *value)
+pt_config_set_string (PtConfig *self,
+                      gchar    *group,
+                      gchar    *parameter,
+                      gchar    *value)
 {
+  PtConfigPrivate *priv = pt_config_get_instance_private (self);
   g_key_file_set_string (
-      config->priv->keyfile, group, parameter, value);
+      priv->keyfile, group, parameter, value);
 
-  return pt_config_save (config);
+  return pt_config_save (self);
 }
 
 /**
  * pt_config_get_name:
- * @config: a configuration instance
+ * @self: a configuration instance
  *
  * The human-visible name to identify a configuration.
  *
@@ -220,17 +226,19 @@ pt_config_set_string (PtConfig *config,
  * Since: 3.0
  */
 gchar *
-pt_config_get_name (PtConfig *config)
+pt_config_get_name (PtConfig *self)
 {
-  g_return_val_if_fail (PT_IS_CONFIG (config), NULL);
-  g_return_val_if_fail (config->priv->is_valid, NULL);
+  g_return_val_if_fail (PT_IS_CONFIG (self), NULL);
 
-  return config->priv->name;
+  PtConfigPrivate *priv = pt_config_get_instance_private (self);
+  g_return_val_if_fail (priv->is_valid, NULL);
+
+  return priv->name;
 }
 
 /**
  * pt_config_set_name:
- * @config: a configuration instance
+ * @self: a configuration instance
  * @name: the new name
  *
  * Sets the human-visible name of a configuration. It doesn’t have to be
@@ -241,28 +249,30 @@ pt_config_get_name (PtConfig *config)
  * Since: 3.0
  */
 gboolean
-pt_config_set_name (PtConfig *config,
-                    gchar *name)
+pt_config_set_name (PtConfig *self,
+                    gchar    *name)
 {
-  g_return_val_if_fail (PT_IS_CONFIG (config), FALSE);
-  g_return_val_if_fail (config->priv->is_valid, FALSE);
+  g_return_val_if_fail (PT_IS_CONFIG (self), FALSE);
 
-  if (g_strcmp0 (config->priv->name, name) == 0)
+  PtConfigPrivate *priv = pt_config_get_instance_private (self);
+  g_return_val_if_fail (priv->is_valid, FALSE);
+
+  if (g_strcmp0 (priv->name, name) == 0)
     return TRUE;
 
-  if (!pt_config_set_string (config, "Model", "Name", name))
+  if (!pt_config_set_string (self, "Model", "Name", name))
     return FALSE;
 
-  g_free (config->priv->name);
-  config->priv->name = g_strdup (name);
-  g_object_notify_by_pspec (G_OBJECT (config),
+  g_free (priv->name);
+  priv->name = g_strdup (name);
+  g_object_notify_by_pspec (G_OBJECT (self),
                             obj_properties[PROP_NAME]);
   return TRUE;
 }
 
 /**
  * pt_config_set_base_folder:
- * @config: a configuration instance
+ * @self: a configuration instance
  * @name: the new base folder
  *
  * Sets the configuration’s base folder.
@@ -272,25 +282,27 @@ pt_config_set_name (PtConfig *config,
  * Since: 3.0
  */
 gboolean
-pt_config_set_base_folder (PtConfig *config,
-                           gchar *name)
+pt_config_set_base_folder (PtConfig *self,
+                           gchar    *name)
 {
-  g_return_val_if_fail (PT_IS_CONFIG (config), FALSE);
-  g_return_val_if_fail (config->priv->is_valid, FALSE);
+  g_return_val_if_fail (PT_IS_CONFIG (self), FALSE);
+
+  PtConfigPrivate *priv = pt_config_get_instance_private (self);
+  g_return_val_if_fail (priv->is_valid, FALSE);
 
   gboolean result;
   gboolean installed;
 
-  result = pt_config_set_string (config, "Model", "BaseFolder", name);
+  result = pt_config_set_string (self, "Model", "BaseFolder", name);
   if (result)
     {
-      g_free (config->priv->base_folder);
-      config->priv->base_folder = g_strdup (name);
-      installed = pt_config_verify_install (config);
-      if (installed != config->priv->is_installed)
+      g_free (priv->base_folder);
+      priv->base_folder = g_strdup (name);
+      installed = pt_config_verify_install (self);
+      if (installed != priv->is_installed)
         {
-          config->priv->is_installed = installed;
-          g_object_notify_by_pspec (G_OBJECT (config),
+          priv->is_installed = installed;
+          g_object_notify_by_pspec (G_OBJECT (self),
                                     obj_properties[PROP_IS_INSTALLED]);
         }
     }
@@ -300,7 +312,7 @@ pt_config_set_base_folder (PtConfig *config,
 
 /**
  * pt_config_get_base_folder:
- * @config: a configuration instance
+ * @self: a configuration instance
  *
  * Gets the configuration’s base folder. If the model is not installed, the
  * base folder is not set and the return value is NULL. Another reason for
@@ -312,17 +324,19 @@ pt_config_set_base_folder (PtConfig *config,
  * Since: 3.0
  */
 gchar *
-pt_config_get_base_folder (PtConfig *config)
+pt_config_get_base_folder (PtConfig *self)
 {
-  g_return_val_if_fail (PT_IS_CONFIG (config), NULL);
-  g_return_val_if_fail (config->priv->is_valid, NULL);
+  g_return_val_if_fail (PT_IS_CONFIG (self), NULL);
 
-  return config->priv->base_folder;
+  PtConfigPrivate *priv = pt_config_get_instance_private (self);
+  g_return_val_if_fail (priv->is_valid, NULL);
+
+  return priv->base_folder;
 }
 
 /**
  * pt_config_get_plugin:
- * @config: a configuration instance
+ * @self: a configuration instance
  *
  * Gets the name of the GStreamer plugin the configuration is intended for.
  * It has to be exactly the string GStreamer uses to instantiate the plugin.
@@ -332,17 +346,19 @@ pt_config_get_base_folder (PtConfig *config)
  * Since: 3.0
  */
 gchar *
-pt_config_get_plugin (PtConfig *config)
+pt_config_get_plugin (PtConfig *self)
 {
-  g_return_val_if_fail (PT_IS_CONFIG (config), NULL);
-  g_return_val_if_fail (config->priv->is_valid, NULL);
+  g_return_val_if_fail (PT_IS_CONFIG (self), NULL);
 
-  return config->priv->plugin;
+  PtConfigPrivate *priv = pt_config_get_instance_private (self);
+  g_return_val_if_fail (priv->is_valid, NULL);
+
+  return priv->plugin;
 }
 
 /**
  * pt_config_get_lang_code:
- * @config: a configuration instance
+ * @self: a configuration instance
  *
  * Gets the language the model was made for. It’s the ISO 639-1 code
  * (2 letters) if available, otherwise ISO 639-2 (3 letters).
@@ -352,17 +368,19 @@ pt_config_get_plugin (PtConfig *config)
  * Since: 3.0
  */
 gchar *
-pt_config_get_lang_code (PtConfig *config)
+pt_config_get_lang_code (PtConfig *self)
 {
-  g_return_val_if_fail (PT_IS_CONFIG (config), NULL);
-  g_return_val_if_fail (config->priv->is_valid, NULL);
+  g_return_val_if_fail (PT_IS_CONFIG (self), NULL);
 
-  return config->priv->lang_code;
+  PtConfigPrivate *priv = pt_config_get_instance_private (self);
+  g_return_val_if_fail (priv->is_valid, NULL);
+
+  return priv->lang_code;
 }
 
 /**
  * pt_config_get_lang_name:
- * @config: a configuration instance
+ * @self: a configuration instance
  *
  * Gets the localized name of the language the model was made for.
  *
@@ -371,17 +389,19 @@ pt_config_get_lang_code (PtConfig *config)
  * Since: 3.0
  */
 gchar *
-pt_config_get_lang_name (PtConfig *config)
+pt_config_get_lang_name (PtConfig *self)
 {
-  g_return_val_if_fail (PT_IS_CONFIG (config), NULL);
-  g_return_val_if_fail (config->priv->is_valid, NULL);
+  g_return_val_if_fail (PT_IS_CONFIG (self), NULL);
 
-  return config->priv->lang_name;
+  PtConfigPrivate *priv = pt_config_get_instance_private (self);
+  g_return_val_if_fail (priv->is_valid, NULL);
+
+  return priv->lang_name;
 }
 
 /**
  * pt_config_get_key:
- * @config: a configuration instance
+ * @self: a configuration instance
  * @key: the name of a key in the [Model] group
  *
  * Get other optional keys in the [Model] group. All keys are assumed to be
@@ -392,18 +412,20 @@ pt_config_get_lang_name (PtConfig *config)
  * Since: 3.0
  */
 gchar *
-pt_config_get_key (PtConfig *config,
-                   gchar *key)
+pt_config_get_key (PtConfig *self,
+                   gchar    *key)
 {
-  g_return_val_if_fail (PT_IS_CONFIG (config), NULL);
-  g_return_val_if_fail (config->priv->is_valid, NULL);
+  g_return_val_if_fail (PT_IS_CONFIG (self), NULL);
 
-  return pt_config_get_string (config, "Model", key);
+  PtConfigPrivate *priv = pt_config_get_instance_private (self);
+  g_return_val_if_fail (priv->is_valid, NULL);
+
+  return pt_config_get_string (self, "Model", key);
 }
 
 /**
  * pt_config_apply:
- * @config: a configuration instance
+ * @self: a configuration instance
  * @plugin: the GStreamer ASR plugin
  * @error: (nullable): return location for an error, or NULL
  *
@@ -414,20 +436,22 @@ pt_config_get_key (PtConfig *config,
  * Since: 3.0
  */
 gboolean
-pt_config_apply (PtConfig *config,
-                 GObject *plugin,
-                 GError **error)
+pt_config_apply (PtConfig *self,
+                 GObject  *plugin,
+                 GError  **error)
 {
-  g_return_val_if_fail (PT_IS_CONFIG (config), FALSE);
-  g_return_val_if_fail (config->priv->is_valid, FALSE);
+  g_return_val_if_fail (PT_IS_CONFIG (self), FALSE);
   g_return_val_if_fail (G_IS_OBJECT (plugin), FALSE);
   g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
 
-  gchar **keys = NULL;
+  PtConfigPrivate *priv = pt_config_get_instance_private (self);
+  g_return_val_if_fail (priv->is_valid, FALSE);
+
+  gchar     **keys = NULL;
   GParamSpec *spec;
-  GType type;
-  GValue value;
-  gchar *groups[] = { "Parameters", "Files", NULL };
+  GType       type;
+  GValue      value;
+  gchar      *groups[] = { "Parameters", "Files", NULL };
 
   g_object_freeze_notify (plugin);
 
@@ -437,7 +461,7 @@ pt_config_apply (PtConfig *config,
   for (int g = 0; groups[g] != NULL; g++)
     {
 
-      keys = g_key_file_get_keys (config->priv->keyfile, groups[g],
+      keys = g_key_file_get_keys (priv->keyfile, groups[g],
                                   NULL, NULL);
 
       /* "Parameters" is optional */
@@ -452,7 +476,8 @@ pt_config_apply (PtConfig *config,
               g_set_error (error,
                            PT_ERROR,
                            PT_ERROR_PLUGIN_MISSING_PROPERTY,
-                           _ ("Plugin doesn’t have a property “%s”"), keys[k]);
+                           /* Translators: %s is replaced with the parameter’s name */
+                           _ ("Plugin doesn’t have a parameter “%s”."), keys[k]);
               g_strfreev (keys);
               g_object_thaw_notify (plugin);
               return FALSE;
@@ -462,14 +487,15 @@ pt_config_apply (PtConfig *config,
               g_set_error (error,
                            PT_ERROR,
                            PT_ERROR_PLUGIN_NOT_WRITABLE,
-                           _ ("Plugin property “%s” is not writable"), keys[k]);
+                           /* Translators: %s is replaced with the parameter’s name */
+                           _ ("Parameter “%s” is not writable."), keys[k]);
               g_strfreev (keys);
               g_object_thaw_notify (plugin);
               return FALSE;
             }
 
           type = G_PARAM_SPEC_VALUE_TYPE (spec);
-          value = pt_config_get_value (config, groups[g], keys[k], type);
+          value = pt_config_get_value (self, groups[g], keys[k], type);
 
           if (g_param_value_validate (spec, &value))
             {
@@ -477,7 +503,8 @@ pt_config_apply (PtConfig *config,
               g_set_error (error,
                            PT_ERROR,
                            PT_ERROR_PLUGIN_WRONG_VALUE,
-                           _ ("Value for property “%s” is not valid"), keys[k]);
+                           /* Translators: %s is replaced with the parameter’s name */
+                           _ ("Value for parameter “%s” is not valid."), keys[k]);
               g_strfreev (keys);
               g_value_unset (&value);
               g_object_thaw_notify (plugin);
@@ -497,13 +524,14 @@ pt_config_apply (PtConfig *config,
 }
 
 static gboolean
-key_is_empty (PtConfig *config,
-              gchar *key)
+key_is_empty (PtConfig *self,
+              gchar    *key)
 {
-  gboolean result = FALSE;
-  gchar *value;
+  PtConfigPrivate *priv = pt_config_get_instance_private (self);
+  gboolean         result = FALSE;
+  gchar           *value;
 
-  value = g_key_file_get_string (config->priv->keyfile, "Model", key, NULL);
+  value = g_key_file_get_string (priv->keyfile, "Model", key, NULL);
 
   if (!value)
     return TRUE;
@@ -514,14 +542,14 @@ key_is_empty (PtConfig *config,
 }
 
 static gboolean
-pt_config_version_is_valid (PtConfig *config)
+pt_config_version_is_valid (PtConfig *self)
 {
-  gchar *version;
-  gchar **version_split;
-  gint64 major;
+  gchar   *version;
+  gchar  **version_split;
+  gint64   major;
   gboolean success;
 
-  version = pt_config_get_string (config, "Model", "Version");
+  version = pt_config_get_string (self, "Model", "Version");
   if (!version || g_strcmp0 (version, "") == 0)
     {
       g_free (version);
@@ -554,7 +582,7 @@ pt_config_version_is_valid (PtConfig *config)
 
 /**
  * pt_config_is_installed:
- * @config: a configuration instance
+ * @self: a configuration instance
  *
  * Checks whether the model is installed, that means the base folder exists
  * and all files listed in the configuration are located inside the base folder.
@@ -564,17 +592,19 @@ pt_config_version_is_valid (PtConfig *config)
  * Since: 3.0
  */
 gboolean
-pt_config_is_installed (PtConfig *config)
+pt_config_is_installed (PtConfig *self)
 {
-  g_return_val_if_fail (PT_IS_CONFIG (config), FALSE);
-  g_return_val_if_fail (config->priv->is_valid, FALSE);
+  g_return_val_if_fail (PT_IS_CONFIG (self), FALSE);
 
-  return config->priv->is_installed;
+  PtConfigPrivate *priv = pt_config_get_instance_private (self);
+  g_return_val_if_fail (priv->is_valid, FALSE);
+
+  return priv->is_installed;
 }
 
 /**
  * pt_config_is_valid:
- * @config: the configuration to test
+ * @self: the configuration to test
  *
  * Checks if a configuration is formally valid:
  * <itemizedlist>
@@ -631,45 +661,47 @@ pt_config_is_installed (PtConfig *config)
  * Since: 3.0
  */
 gboolean
-pt_config_is_valid (PtConfig *config)
+pt_config_is_valid (PtConfig *self)
 {
-  g_return_val_if_fail (PT_IS_CONFIG (config), FALSE);
+  g_return_val_if_fail (PT_IS_CONFIG (self), FALSE);
 
-  return config->priv->is_valid;
+  PtConfigPrivate *priv = pt_config_get_instance_private (self);
+  return priv->is_valid;
 }
 
 static gboolean
-is_valid (PtConfig *config)
+is_valid (PtConfig *self)
 {
-  gchar *groups[] = { "Model", "Files", NULL };
-  gchar *model_keys[] = { "Name", "Plugin", "BaseFolder", "Language", NULL };
-  gchar *mandatory[] = { "Name", "Plugin", "Language", NULL };
-  gchar **parameters = NULL;
-  gboolean valid = TRUE;
-  int i;
+  PtConfigPrivate *priv = pt_config_get_instance_private (self);
+  gchar           *groups[] = { "Model", "Files", NULL };
+  gchar           *model_keys[] = { "Name", "Plugin", "BaseFolder", "Language", NULL };
+  gchar           *mandatory[] = { "Name", "Plugin", "Language", NULL };
+  gchar          **parameters = NULL;
+  gboolean         valid = TRUE;
+  int              i;
 
   for (i = 0; groups[i] != NULL; i++)
     {
-      if (!g_key_file_has_group (config->priv->keyfile, groups[i]))
+      if (!g_key_file_has_group (priv->keyfile, groups[i]))
         return FALSE;
     }
 
-  if (!pt_config_version_is_valid (config))
+  if (!pt_config_version_is_valid (self))
     return FALSE;
 
   for (i = 0; model_keys[i] != NULL; i++)
     {
-      if (!g_key_file_has_key (config->priv->keyfile, "Model", model_keys[i], NULL))
+      if (!g_key_file_has_key (priv->keyfile, "Model", model_keys[i], NULL))
         return FALSE;
     }
 
   for (i = 0; mandatory[i] != NULL; i++)
     {
-      if (key_is_empty (config, mandatory[i]))
+      if (key_is_empty (self, mandatory[i]))
         return FALSE;
     }
 
-  parameters = g_key_file_get_keys (config->priv->keyfile, "Files",
+  parameters = g_key_file_get_keys (priv->keyfile, "Files",
                                     NULL, NULL);
 
   if (!parameters || parameters[0] == NULL)
@@ -680,28 +712,29 @@ is_valid (PtConfig *config)
 }
 
 static gboolean
-pt_config_verify_install (PtConfig *config)
+pt_config_verify_install (PtConfig *self)
 {
-  gchar **keys = NULL;
-  GValue value;
-  gboolean result = TRUE;
+  PtConfigPrivate *priv = pt_config_get_instance_private (self);
+  gchar          **keys = NULL;
+  GValue           value;
+  gboolean         result = TRUE;
 
-  if (!config->priv->base_folder)
+  if (!priv->base_folder)
     return FALSE;
 
-  if (!g_file_test (config->priv->base_folder, G_FILE_TEST_IS_DIR | G_FILE_TEST_EXISTS))
+  if (!g_file_test (priv->base_folder, G_FILE_TEST_IS_DIR | G_FILE_TEST_EXISTS))
     {
       g_log_structured (G_LOG_DOMAIN, G_LOG_LEVEL_INFO,
-                        "MESSAGE", "Base folder \"%s\" not found", config->priv->base_folder);
+                        "MESSAGE", "Base folder \"%s\" not found", priv->base_folder);
       return FALSE;
     }
 
-  keys = g_key_file_get_keys (config->priv->keyfile, "Files",
+  keys = g_key_file_get_keys (priv->keyfile, "Files",
                               NULL, NULL);
 
   for (int i = 0; keys[i] != NULL; i++)
     {
-      value = pt_config_get_value (config, "Files", keys[i], G_TYPE_NONE);
+      value = pt_config_get_value (self, "Files", keys[i], G_TYPE_NONE);
       result = g_file_test (g_value_get_string (&value), G_FILE_TEST_EXISTS);
       if (!result)
         g_log_structured (G_LOG_DOMAIN, G_LOG_LEVEL_INFO,
@@ -746,11 +779,11 @@ tabula_rasa (PtConfigPrivate *priv)
 }
 
 static void
-setup_config (PtConfig *config)
+setup_config (PtConfig *self)
 {
-  PtConfigPrivate *priv = config->priv;
-  GError *error = NULL;
-  gboolean loaded;
+  PtConfigPrivate *priv = pt_config_get_instance_private (self);
+  GError          *error = NULL;
+  gboolean         loaded;
 
   priv->keyfile = g_key_file_new ();
   g_key_file_set_list_separator (priv->keyfile, '/');
@@ -775,23 +808,23 @@ setup_config (PtConfig *config)
       g_error_free (error);
     }
 
-  if (!loaded || !is_valid (config))
+  if (!loaded || !is_valid (self))
     return;
 
   priv->is_valid = TRUE;
-  priv->name = pt_config_get_string (config, "Model", "Name");
-  priv->plugin = pt_config_get_string (config, "Model", "Plugin");
-  priv->base_folder = pt_config_get_string (config, "Model", "BaseFolder");
-  priv->lang_code = pt_config_get_string (config, "Model", "Language");
-  priv->lang_name = gnome_get_language_from_locale (config->priv->lang_code, NULL);
+  priv->name = pt_config_get_string (self, "Model", "Name");
+  priv->plugin = pt_config_get_string (self, "Model", "Plugin");
+  priv->base_folder = pt_config_get_string (self, "Model", "BaseFolder");
+  priv->lang_code = pt_config_get_string (self, "Model", "Language");
+  priv->lang_name = gnome_get_language_from_locale (priv->lang_code, NULL);
   if (!priv->lang_name)
     priv->lang_name = g_strdup (priv->lang_code);
-  priv->is_installed = pt_config_verify_install (config);
+  priv->is_installed = pt_config_verify_install (self);
 }
 
 /**
  * pt_config_get_file:
- * @config: a configuration instance
+ * @self: a configuration instance
  *
  * The #GFile that storing the configuration.
  *
@@ -800,17 +833,19 @@ setup_config (PtConfig *config)
  * Since: 3.0
  */
 GFile *
-pt_config_get_file (PtConfig *config)
+pt_config_get_file (PtConfig *self)
 {
-  g_return_val_if_fail (PT_IS_CONFIG (config), NULL);
-  g_return_val_if_fail (config->priv->is_valid, NULL);
+  g_return_val_if_fail (PT_IS_CONFIG (self), NULL);
 
-  return config->priv->file;
+  PtConfigPrivate *priv = pt_config_get_instance_private (self);
+  g_return_val_if_fail (priv->is_valid, NULL);
+
+  return priv->file;
 }
 
 /**
  * pt_config_set_file:
- * @config: a configuration instance
+ * @self: a configuration instance
  * @file: the new file
  *
  * Sets a new file, invalidating all fields and reevaluating status.
@@ -818,26 +853,26 @@ pt_config_get_file (PtConfig *config)
  * Since: 3.0
  */
 void
-pt_config_set_file (PtConfig *config,
-                    GFile *file)
+pt_config_set_file (PtConfig *self,
+                    GFile    *file)
 {
-  g_return_if_fail (PT_IS_CONFIG (config));
+  g_return_if_fail (PT_IS_CONFIG (self));
   g_return_if_fail (file != NULL);
 
-  PtConfigPrivate *priv = config->priv;
+  PtConfigPrivate *priv = pt_config_get_instance_private (self);
 
   free_private (priv);
   tabula_rasa (priv);
-  config->priv->file = g_object_ref (file);
-  setup_config (config);
+  priv->file = g_object_ref (file);
+  setup_config (self);
 }
 
 static void
-pt_config_init (PtConfig *config)
+pt_config_init (PtConfig *self)
 {
-  config->priv = pt_config_get_instance_private (config);
+  PtConfigPrivate *priv = pt_config_get_instance_private (self);
 
-  tabula_rasa (config->priv);
+  tabula_rasa (priv);
 }
 
 static void
@@ -849,25 +884,26 @@ pt_config_dispose (GObject *object)
 static void
 pt_config_finalize (GObject *object)
 {
-  PtConfig *config = PT_CONFIG (object);
+  PtConfig        *self = PT_CONFIG (object);
+  PtConfigPrivate *priv = pt_config_get_instance_private (self);
 
-  free_private (config->priv);
+  free_private (priv);
 
   G_OBJECT_CLASS (pt_config_parent_class)->finalize (object);
 }
 
 static void
-pt_config_set_property (GObject *object,
-                        guint property_id,
+pt_config_set_property (GObject      *object,
+                        guint         property_id,
                         const GValue *value,
-                        GParamSpec *pspec)
+                        GParamSpec   *pspec)
 {
-  PtConfig *config = PT_CONFIG (object);
+  PtConfig *self = PT_CONFIG (object);
 
   switch (property_id)
     {
     case PROP_FILE:
-      pt_config_set_file (config, g_value_get_object (value));
+      pt_config_set_file (self, g_value_get_object (value));
       break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -876,26 +912,27 @@ pt_config_set_property (GObject *object,
 }
 
 static void
-pt_config_get_property (GObject *object,
-                        guint property_id,
-                        GValue *value,
+pt_config_get_property (GObject    *object,
+                        guint       property_id,
+                        GValue     *value,
                         GParamSpec *pspec)
 {
-  PtConfig *config = PT_CONFIG (object);
+  PtConfig        *self = PT_CONFIG (object);
+  PtConfigPrivate *priv = pt_config_get_instance_private (self);
 
   switch (property_id)
     {
     case PROP_FILE:
-      g_value_set_object (value, config->priv->file);
+      g_value_set_object (value, priv->file);
       break;
     case PROP_IS_VALID:
-      g_value_set_boolean (value, config->priv->is_valid);
+      g_value_set_boolean (value, priv->is_valid);
       break;
     case PROP_IS_INSTALLED:
-      g_value_set_boolean (value, config->priv->is_installed);
+      g_value_set_boolean (value, priv->is_installed);
       break;
     case PROP_NAME:
-      g_value_set_string (value, config->priv->name);
+      g_value_set_string (value, priv->name);
       break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -920,11 +957,9 @@ pt_config_class_init (PtConfigClass *klass)
    */
   obj_properties[PROP_FILE] =
       g_param_spec_object (
-          "file",
-          "File",
-          "File used to construct object",
+          "file", NULL, NULL,
           G_TYPE_FILE,
-          G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY);
+          G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_STRINGS);
 
   /**
    * PtConfig:is-valid:
@@ -936,11 +971,9 @@ pt_config_class_init (PtConfigClass *klass)
    */
   obj_properties[PROP_IS_VALID] =
       g_param_spec_boolean (
-          "is-valid",
-          "Valid",
-          "Whether the config is formally valid",
+          "is-valid", NULL, NULL,
           FALSE,
-          G_PARAM_READABLE);
+          G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
 
   /**
    * PtConfig:is-installed:
@@ -949,11 +982,9 @@ pt_config_class_init (PtConfigClass *klass)
    */
   obj_properties[PROP_IS_INSTALLED] =
       g_param_spec_boolean (
-          "is-installed",
-          "Installed",
-          "Whether the language model is installed",
+          "is-installed", NULL, NULL,
           FALSE,
-          G_PARAM_READABLE);
+          G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
 
   /**
    * PtConfig:name:
@@ -962,11 +993,9 @@ pt_config_class_init (PtConfigClass *klass)
    */
   obj_properties[PROP_NAME] =
       g_param_spec_string (
-          "name",
-          "Name",
-          "Display name for the model",
+          "name", NULL, NULL,
           NULL,
-          G_PARAM_READABLE);
+          G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
 
   g_object_class_install_properties (
       G_OBJECT_CLASS (klass),
