@@ -1,4 +1,4 @@
-/* Copyright (C) Gabor Karsay 2020 <gabor.karsay@gmx.at>
+/* Copyright 2020 Gabor Karsay <gabor.karsay@gmx.at>
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as published
@@ -14,8 +14,7 @@
  * with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef PT_CONFIG_H
-#define PT_CONFIG_H
+#pragma once
 
 #if !defined(__PARLATYPE_H_INSIDE__) && !defined(PARLATYPE_COMPILATION)
 #error "Only <parlatype.h> can be included directly."
@@ -23,26 +22,10 @@
 
 #include <gio/gio.h>
 
+G_BEGIN_DECLS
+
 #define PT_TYPE_CONFIG (pt_config_get_type ())
-#define PT_CONFIG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PT_TYPE_CONFIG, PtConfig))
-#define PT_IS_CONFIG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PT_TYPE_CONFIG))
-
-typedef struct _PtConfig PtConfig;
-typedef struct _PtConfigClass PtConfigClass;
-typedef struct _PtConfigPrivate PtConfigPrivate;
-
-/**
- * PtConfig:
- *
- * #PtConfig contains only private fields and should not be directly accessed.
- */
-struct _PtConfig
-{
-  GObject parent;
-
-  /*< private > */
-  PtConfigPrivate *priv;
-};
+G_DECLARE_DERIVABLE_TYPE (PtConfig, pt_config, PT, CONFIG, GObject)
 
 struct _PtConfigClass
 {
@@ -72,30 +55,40 @@ typedef enum
   PT_ERROR_PLUGIN_WRONG_VALUE,
 } PtError;
 
-GType pt_config_get_type (void) G_GNUC_CONST;
 GQuark pt_error_quark (void);
 
-gchar *pt_config_get_name (PtConfig *config);
-gboolean pt_config_set_name (PtConfig *config,
-                             gchar *name);
-gchar *pt_config_get_base_folder (PtConfig *config);
-gboolean pt_config_set_base_folder (PtConfig *config,
-                                    gchar *name);
-gchar *pt_config_get_plugin (PtConfig *config);
-gchar *pt_config_get_lang_code (PtConfig *config);
-gchar *pt_config_get_lang_name (PtConfig *config);
-gchar *pt_config_get_key (PtConfig *config,
-                          gchar *key);
+gchar    *pt_config_get_name        (PtConfig *self);
 
-GFile *pt_config_get_file (PtConfig *config);
-void pt_config_set_file (PtConfig *config,
-                         GFile *file);
+gboolean  pt_config_set_name        (PtConfig *self,
+                                     gchar    *name);
 
-gboolean pt_config_apply (PtConfig *config,
-                          GObject *plugin,
-                          GError **error);
-gboolean pt_config_is_valid (PtConfig *config);
-gboolean pt_config_is_installed (PtConfig *config);
-PtConfig *pt_config_new (GFile *file);
+gchar    *pt_config_get_base_folder (PtConfig *self);
 
-#endif
+gboolean  pt_config_set_base_folder (PtConfig *self,
+                                     gchar    *name);
+
+gchar    *pt_config_get_plugin      (PtConfig *self);
+
+gchar    *pt_config_get_lang_code   (PtConfig *self);
+
+gchar    *pt_config_get_lang_name   (PtConfig *self);
+
+gchar    *pt_config_get_key         (PtConfig *self,
+                                     gchar    *key);
+
+GFile    *pt_config_get_file        (PtConfig *self);
+
+void      pt_config_set_file        (PtConfig *self,
+                                     GFile    *file);
+
+gboolean  pt_config_apply           (PtConfig *self,
+                                     GObject  *plugin,
+                                     GError  **error);
+
+gboolean  pt_config_is_valid        (PtConfig *self);
+
+gboolean  pt_config_is_installed    (PtConfig *self);
+
+PtConfig *pt_config_new             (GFile *file);
+
+G_END_DECLS
