@@ -1,4 +1,4 @@
-/* Copyright (C) Gabor Karsay 2019 <gabor.karsay@gmx.at>
+/* Copyright 2019 Gabor Karsay <gabor.karsay@gmx.at>
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as published
@@ -14,15 +14,6 @@
  * with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef PT_I18N_H
-#define PT_I18N_H
-
-#include <gio/gio.h>
-
-G_BEGIN_DECLS
+#pragma once
 
 void _pt_i18n_init (void);
-
-G_END_DECLS
-
-#endif
