@@ -1,5 +1,5 @@
 /* Copyright (C) 2006 Buzztrax team <buzztrax-devel@buzztrax.org>
- * Copyright (C) Gabor Karsay 2016, 2020 <gabor.karsay@gmx.at>
+ * Copyright 2016 Gabor Karsay <gabor.karsay@gmx.at>
  *
  * Taken from wave.c (bt_wave_load_from_uri) from Buzztrax and heavily modified.
  *
@@ -27,42 +27,46 @@
  * used by a widget to visually represent a waveform.
  */
 
-#include "config.h"
-#include <gio/gio.h>
 #define GETTEXT_PACKAGE GETTEXT_LIB
-#include <glib/gi18n-lib.h>
-#include <gst/gst.h>
-#include <gst/audio/audio.h>
-#include <gst/app/gstappsink.h>
-#include "pt-i18n.h"
+
+#include "config.h"
+
 #include "pt-waveloader.h"
 
+#include "pt-i18n.h"
+
+#include <gio/gio.h>
+#include <glib/gi18n-lib.h>
+#include <gst/app/gstappsink.h>
+#include <gst/audio/audio.h>
+#include <gst/gst.h>
+
+typedef struct _PtWaveloaderPrivate PtWaveloaderPrivate;
 struct _PtWaveloaderPrivate
 {
   GstElement *pipeline;
   GstElement *fmt;
 
   GArray *hires;
-  gint hires_index;
+  gint    hires_index;
   GArray *lowres;
-  gint pps;
-  gint lowres_index;
+  gint    pps;
+  gint    lowres_index;
 
-  gchar *uri;
+  gchar   *uri;
   gboolean load_pending;
   gboolean data_pending;
 
   gint64 duration;
 
-  gint bus_watch_id;
-  gint progress_timeout;
+  gint    bus_watch_id;
+  gint    progress_timeout;
   gdouble progress;
 };
 
 enum
 {
-  PROP_0,
-  PROP_URI,
+  PROP_URI = 1,
   N_PROPERTIES
 };
 
@@ -73,27 +77,27 @@ enum
   LAST_SIGNAL
 };
 
-static GParamSpec *obj_properties[N_PROPERTIES] = {
-  NULL,
-};
-static guint signals[LAST_SIGNAL] = { 0 };
+static GParamSpec *obj_properties[N_PROPERTIES];
+static guint       signals[LAST_SIGNAL] = { 0 };
 
 G_DEFINE_TYPE_WITH_PRIVATE (PtWaveloader, pt_waveloader, G_TYPE_OBJECT)
 
 static void
-remove_timeout (PtWaveloader *wl)
+remove_timeout (PtWaveloader *self)
 {
-  if (wl->priv->progress_timeout > 0)
+  PtWaveloaderPrivate *priv = pt_waveloader_get_instance_private (self);
+
+  if (priv->progress_timeout > 0)
     {
-      g_source_remove (wl->priv->progress_timeout);
-      wl->priv->progress_timeout = 0;
+      g_source_remove (priv->progress_timeout);
+      priv->progress_timeout = 0;
     }
 }
 
 static void
 on_wave_loader_new_pad (GstElement *bin,
-                        GstPad *pad,
-                        gpointer user_data)
+                        GstPad     *pad,
+                        gpointer    user_data)
 {
   if (!gst_element_link (bin, GST_ELEMENT (user_data)))
     {
@@ -144,15 +148,15 @@ calc_lowres_len (gint hires_len,
 static void
 convert_one_second (GArray *in,
                     GArray *out,
-                    gint *index_in,
-                    gint *index_out,
-                    gint pps)
+                    gint   *index_in,
+                    gint   *index_out,
+                    gint    pps)
 {
-  gint k, m;
+  gint   k, m;
   gint16 d;
   gfloat vmin, vmax;
-  gint chunk_size;
-  gint mod;
+  gint   chunk_size;
+  gint   mod;
 
   chunk_size = 8000 / pps;
   mod = 8000 % pps;
@@ -203,12 +207,13 @@ convert_one_second (GArray *in,
 
 static GstFlowReturn
 new_sample_cb (GstAppSink *sink,
-               gpointer user_data)
+               gpointer    user_data)
 {
-  PtWaveloader *wl = PT_WAVELOADER (user_data);
-  GstSample *sample = gst_app_sink_pull_sample (sink);
-  GstBuffer *buffer = gst_sample_get_buffer (sample);
-  GstMapInfo map;
+  PtWaveloader        *self = PT_WAVELOADER (user_data);
+  PtWaveloaderPrivate *priv = pt_waveloader_get_instance_private (self);
+  GstSample           *sample = gst_app_sink_pull_sample (sink);
+  GstBuffer           *buffer = gst_sample_get_buffer (sample);
+  GstMapInfo           map;
   if (!gst_buffer_map (buffer, &map, GST_MAP_READ))
     {
       gst_sample_unref (sample);
@@ -217,27 +222,27 @@ new_sample_cb (GstAppSink *sink,
   /* One sample is 2 bytes (16 bit signed integer), see caps in
    * setup_pipeline(). The buffer contains several samples, the number
    * of elements/samples is map.size / sample size. */
-  g_array_append_vals (wl->priv->hires, map.data, map.size / 2);
+  g_array_append_vals (priv->hires, map.data, map.size / 2);
   gst_buffer_unmap (buffer, &map);
   gst_sample_unref (sample);
 
   /* If hires has more than one second of new data available, add it to
    * lowres. The very last data will be added at the EOS signal. */
-  gint pps = wl->priv->pps;
-  if (wl->priv->hires->len - wl->priv->hires_index >= 8000)
+  gint pps = priv->pps;
+  if (priv->hires->len - priv->hires_index >= 8000)
     {
       /* Make sure lowres is big enough */
-      if (wl->priv->lowres_index + pps * 2 + 1 > wl->priv->lowres->len)
+      if (priv->lowres_index + pps * 2 + 1 > priv->lowres->len)
         {
-          g_array_set_size (wl->priv->lowres, wl->priv->lowres_index + pps * 2 + 2);
+          g_array_set_size (priv->lowres, priv->lowres_index + pps * 2 + 2);
           g_log_structured (G_LOG_DOMAIN, G_LOG_LEVEL_DEBUG,
                             "MESSAGE", "lowres->len resized in new_sample_cb: %d",
-                            wl->priv->lowres_index + pps * 2 + 2);
+                            priv->lowres_index + pps * 2 + 2);
         }
-      convert_one_second (wl->priv->hires,
-                          wl->priv->lowres,
-                          &wl->priv->hires_index,
-                          &wl->priv->lowres_index,
+      convert_one_second (priv->hires,
+                          priv->lowres,
+                          &priv->hires_index,
+                          &priv->lowres_index,
                           pps);
     }
 
@@ -245,21 +250,22 @@ new_sample_cb (GstAppSink *sink,
 }
 
 static gboolean
-setup_pipeline (PtWaveloader *wl)
+setup_pipeline (PtWaveloader *self)
 {
-  gboolean result = TRUE;
-  GstElement *src, *dec, *conv, *resample, *sink;
-  GstCaps *caps;
+  PtWaveloaderPrivate *priv = pt_waveloader_get_instance_private (self);
+  gboolean             result = TRUE;
+  GstElement          *src, *dec, *conv, *resample, *sink;
+  GstCaps             *caps;
 
   /* create loader pipeline TODO: this is probably leaking on 2nd run */
-  wl->priv->pipeline = gst_pipeline_new ("wave-loader");
+  priv->pipeline = gst_pipeline_new ("wave-loader");
 
   /* TODO gst_element_make_from_uri(): The URI must be gst_uri_is_valid(). */
-  src = gst_element_make_from_uri (GST_URI_SRC, wl->priv->uri, NULL, NULL);
+  src = gst_element_make_from_uri (GST_URI_SRC, priv->uri, NULL, NULL);
   dec = gst_element_factory_make ("decodebin", NULL);
   conv = gst_element_factory_make ("audioconvert", NULL);
   resample = gst_element_factory_make ("audioresample", NULL);
-  wl->priv->fmt = gst_element_factory_make ("capsfilter", NULL);
+  priv->fmt = gst_element_factory_make ("capsfilter", NULL);
   sink = gst_element_factory_make ("appsink", NULL);
 
   /* configure elements */
@@ -269,32 +275,32 @@ setup_pipeline (PtWaveloader *wl)
                               "channels", G_TYPE_INT, 1,
                               "rate", G_TYPE_INT, 8000, NULL);
 
-  g_object_set (wl->priv->fmt, "caps", caps, NULL);
+  g_object_set (priv->fmt, "caps", caps, NULL);
   gst_caps_unref (caps);
 
   g_object_set (sink, "emit-signals", TRUE, "sync", FALSE, NULL);
 
   /* add and link */
-  gst_bin_add_many (GST_BIN (wl->priv->pipeline), src, dec, conv, resample, wl->priv->fmt, sink, NULL);
+  gst_bin_add_many (GST_BIN (priv->pipeline), src, dec, conv, resample, priv->fmt, sink, NULL);
   result = gst_element_link (src, dec);
   if (!result)
     {
-      GST_WARNING_OBJECT (wl->priv->pipeline,
+      GST_WARNING_OBJECT (priv->pipeline,
                           "Can’t link wave loader pipeline (src ! dec ! conv ! resample ! fmt ! sink).");
       return result;
     }
 
-  result = gst_element_link_many (conv, resample, wl->priv->fmt, sink, NULL);
+  result = gst_element_link_many (conv, resample, priv->fmt, sink, NULL);
   if (!result)
     {
-      GST_WARNING_OBJECT (wl->priv->pipeline,
+      GST_WARNING_OBJECT (priv->pipeline,
                           "Can’t link wave loader pipeline (conv ! resample ! fmt ! sink).");
       return result;
     }
 
   g_signal_connect (dec, "pad-added", G_CALLBACK (on_wave_loader_new_pad),
                     (gpointer) conv);
-  g_signal_connect (sink, "new-sample", G_CALLBACK (new_sample_cb), wl);
+  g_signal_connect (sink, "new-sample", G_CALLBACK (new_sample_cb), self);
 
   return result;
 }
@@ -306,22 +312,23 @@ check_progress (GTask *task)
      If it’s removed, the message bus has to be removed, too, and also
      the other way round. */
 
-  PtWaveloader *wl = g_task_get_source_object (task);
+  PtWaveloader        *self = g_task_get_source_object (task);
+  PtWaveloaderPrivate *priv = pt_waveloader_get_instance_private (self);
 
-  gint64 dur;
-  gint64 pos;
+  gint64  dur;
+  gint64  pos;
   gdouble temp;
-  gint new_size;
+  gint    new_size;
 
   /* Check if task was cancelled and reset pipeline */
 
   if (g_cancellable_is_cancelled (g_task_get_cancellable (task)))
     {
-      gst_element_set_state (wl->priv->pipeline, GST_STATE_NULL);
-      g_source_remove (wl->priv->bus_watch_id);
-      wl->priv->bus_watch_id = 0;
-      wl->priv->progress_timeout = 0;
-      g_array_set_size (wl->priv->lowres, 0);
+      gst_element_set_state (priv->pipeline, GST_STATE_NULL);
+      g_source_remove (priv->bus_watch_id);
+      priv->bus_watch_id = 0;
+      priv->progress_timeout = 0;
+      g_array_set_size (priv->lowres, 0);
       g_task_return_boolean (task, FALSE);
       g_object_unref (task);
       return G_SOURCE_REMOVE;
@@ -329,53 +336,54 @@ check_progress (GTask *task)
 
   /* Query position and duration and emit progress signal */
 
-  if (!gst_element_query_position (wl->priv->pipeline, GST_FORMAT_TIME, &pos))
+  if (!gst_element_query_position (priv->pipeline, GST_FORMAT_TIME, &pos))
     return G_SOURCE_CONTINUE;
 
-  if (!gst_element_query_duration (wl->priv->pipeline, GST_FORMAT_TIME, &dur))
+  if (!gst_element_query_duration (priv->pipeline, GST_FORMAT_TIME, &dur))
     return G_SOURCE_CONTINUE;
 
-  if (dur > wl->priv->duration)
+  if (dur > priv->duration)
     {
-      wl->priv->duration = dur;
-      new_size = wl->priv->duration / 1000000000 * wl->priv->pps * 2;
-      if (wl->priv->lowres->len != new_size)
+      priv->duration = dur;
+      new_size = priv->duration / 1000000000 * priv->pps * 2;
+      if (priv->lowres->len != new_size)
         {
-          g_array_set_size (wl->priv->lowres, new_size);
+          g_array_set_size (priv->lowres, new_size);
           g_log_structured (G_LOG_DOMAIN, G_LOG_LEVEL_DEBUG,
                             "MESSAGE", "Duration changed signal: %" GST_TIME_FORMAT " lowres resized to len %d",
-                            GST_TIME_ARGS (wl->priv->duration), new_size);
-          g_signal_emit_by_name (wl, "array-size-changed");
+                            GST_TIME_ARGS (priv->duration), new_size);
+          g_signal_emit_by_name (self, "array-size-changed");
         }
     }
 
   temp = (gdouble) pos / dur;
 
-  if (temp > wl->priv->progress && temp < 1)
+  if (temp > priv->progress && temp < 1)
     {
-      wl->priv->progress = temp;
-      g_signal_emit_by_name (wl, "progress", wl->priv->progress);
+      priv->progress = temp;
+      g_signal_emit_by_name (self, "progress", priv->progress);
     }
 
   return G_SOURCE_CONTINUE;
 }
 
 static gboolean
-bus_handler (GstBus *bus,
+bus_handler (GstBus     *bus,
              GstMessage *msg,
-             gpointer data)
+             gpointer    data)
 {
-  GTask *task = (GTask *) data;
-  PtWaveloader *wl = g_task_get_source_object (task);
+  GTask               *task = (GTask *) data;
+  PtWaveloader        *self = g_task_get_source_object (task);
+  PtWaveloaderPrivate *priv = pt_waveloader_get_instance_private (self);
 
   switch (GST_MESSAGE_TYPE (msg))
     {
     case GST_MESSAGE_ERROR:
       {
-        gchar *debug;
+        gchar  *debug;
         GError *error;
 
-        remove_timeout (wl);
+        remove_timeout (self);
         gst_message_parse_error (msg, &error, &debug);
 
         /* Error is returned. Log the message here at level DEBUG,
@@ -386,7 +394,7 @@ bus_handler (GstBus *bus,
         g_log_structured (G_LOG_DOMAIN, G_LOG_LEVEL_DEBUG,
                           "MESSAGE", "Debugging info: %s", (debug) ? debug : "none");
         g_free (debug);
-        wl->priv->bus_watch_id = 0;
+        priv->bus_watch_id = 0;
         g_task_return_error (task, error);
         g_object_unref (task);
         return FALSE;
@@ -396,44 +404,44 @@ bus_handler (GstBus *bus,
       {
 
         /* convert remaining data from hires to lowres */
-        g_array_set_size (wl->priv->lowres, calc_lowres_len (wl->priv->hires->len, wl->priv->pps));
+        g_array_set_size (priv->lowres, calc_lowres_len (priv->hires->len, priv->pps));
 
         /* while hires has more full seconds than lowres ... */
-        while (wl->priv->hires->len > wl->priv->hires_index)
+        while (priv->hires->len > priv->hires_index)
           {
-            convert_one_second (wl->priv->hires,
-                                wl->priv->lowres,
-                                &wl->priv->hires_index,
-                                &wl->priv->lowres_index,
-                                wl->priv->pps);
+            convert_one_second (priv->hires,
+                                priv->lowres,
+                                &priv->hires_index,
+                                &priv->lowres_index,
+                                priv->pps);
           }
 
         /* query length and convert to samples */
-        if (!gst_element_query_duration (wl->priv->pipeline, GST_FORMAT_TIME, &wl->priv->duration))
+        if (!gst_element_query_duration (priv->pipeline, GST_FORMAT_TIME, &priv->duration))
           {
             GST_WARNING ("getting sample duration failed");
           }
 
         g_log_structured (G_LOG_DOMAIN, G_LOG_LEVEL_DEBUG,
                           "MESSAGE", "Sample decoded: hires->len=%d, lowres->len=%d, pps=%d, duration=%" GST_TIME_FORMAT,
-                          wl->priv->hires->len, wl->priv->lowres->len, wl->priv->pps, GST_TIME_ARGS (wl->priv->duration));
+                          priv->hires->len, priv->lowres->len, priv->pps, GST_TIME_ARGS (priv->duration));
 
-        remove_timeout (wl);
-        wl->priv->bus_watch_id = 0;
+        remove_timeout (self);
+        priv->bus_watch_id = 0;
         g_task_return_boolean (task, TRUE);
         g_object_unref (task);
         return FALSE;
       }
     case GST_MESSAGE_DURATION_CHANGED:
       {
-        gst_element_query_duration (wl->priv->pipeline, GST_FORMAT_TIME, &wl->priv->duration);
+        gst_element_query_duration (priv->pipeline, GST_FORMAT_TIME, &priv->duration);
         gint new_size;
-        new_size = wl->priv->duration / 1000000000 * wl->priv->pps * 2;
-        g_array_set_size (wl->priv->lowres, new_size);
+        new_size = priv->duration / 1000000000 * priv->pps * 2;
+        g_array_set_size (priv->lowres, new_size);
         g_log_structured (G_LOG_DOMAIN, G_LOG_LEVEL_DEBUG,
                           "MESSAGE", "Duration changed signal: %" GST_TIME_FORMAT " lowres resized to len %d",
-                          GST_TIME_ARGS (wl->priv->duration), new_size);
-        g_signal_emit_by_name (wl, "array-size-changed");
+                          GST_TIME_ARGS (priv->duration), new_size);
+        g_signal_emit_by_name (self, "array-size-changed");
         break;
       }
     default:
@@ -445,7 +453,7 @@ bus_handler (GstBus *bus,
 
 /**
  * pt_waveloader_load_finish:
- * @wl: a #PtWaveloader
+ * @self: a #PtWaveloader
  * @result: the #GAsyncResult passed to your #GAsyncReadyCallback
  * @error: (nullable): a pointer to a NULL #GError, or NULL
  *
@@ -457,20 +465,21 @@ bus_handler (GstBus *bus,
  * Since: 1.4
  */
 gboolean
-pt_waveloader_load_finish (PtWaveloader *wl,
+pt_waveloader_load_finish (PtWaveloader *self,
                            GAsyncResult *result,
-                           GError **error)
+                           GError      **error)
 {
-  g_return_val_if_fail (g_task_is_valid (result, wl), FALSE);
+  g_return_val_if_fail (g_task_is_valid (result, self), FALSE);
+  PtWaveloaderPrivate *priv = pt_waveloader_get_instance_private (self);
 
-  wl->priv->load_pending = FALSE;
-  g_signal_emit_by_name (wl, "progress", result ? 1.0 : 0.0);
+  priv->load_pending = FALSE;
+  g_signal_emit_by_name (self, "progress", result ? 1.0 : 0.0);
   return g_task_propagate_boolean (G_TASK (result), error);
 }
 
 /**
  * pt_waveloader_load_async:
- * @wl: a #PtWaveloader
+ * @self: a #PtWaveloader
  * @pps: pixels per second
  * @cancellable: (nullable): a #GCancellable or NULL
  * @callback: (scope async): a #GAsyncReadyCallback to call when the operation is complete
@@ -494,26 +503,27 @@ pt_waveloader_load_finish (PtWaveloader *wl,
  * Since: 2.0
  */
 void
-pt_waveloader_load_async (PtWaveloader *wl,
-                          gint pps,
-                          GCancellable *cancellable,
+pt_waveloader_load_async (PtWaveloader       *self,
+                          gint                pps,
+                          GCancellable       *cancellable,
                           GAsyncReadyCallback callback,
-                          gpointer user_data)
+                          gpointer            user_data)
 {
-  g_return_if_fail (PT_IS_WAVELOADER (wl));
-  g_return_if_fail (wl->priv->uri != NULL);
+  g_return_if_fail (PT_IS_WAVELOADER (self));
+  PtWaveloaderPrivate *priv = pt_waveloader_get_instance_private (self);
+  g_return_if_fail (priv->uri != NULL);
 
-  GTask *task;
+  GTask  *task;
   GstBus *bus;
 
-  task = g_task_new (wl, cancellable, callback, user_data);
+  task = g_task_new (self, cancellable, callback, user_data);
   /* Lets have an initial size of 60 sec */
-  g_array_set_size (wl->priv->lowres, pps * 60);
-  wl->priv->pps = pps;
-  wl->priv->lowres_index = 0;
-  wl->priv->hires_index = 0;
+  g_array_set_size (priv->lowres, pps * 60);
+  priv->pps = pps;
+  priv->lowres_index = 0;
+  priv->hires_index = 0;
 
-  if (wl->priv->load_pending)
+  if (priv->load_pending)
     {
       g_task_return_new_error (
           task,
@@ -524,12 +534,12 @@ pt_waveloader_load_async (PtWaveloader *wl,
       return;
     }
 
-  wl->priv->load_pending = TRUE;
-  wl->priv->progress = 0;
-  g_array_set_size (wl->priv->hires, 0);
+  priv->load_pending = TRUE;
+  priv->progress = 0;
+  g_array_set_size (priv->hires, 0);
 
   /* setup pipeline TODO: do it just on init */
-  if (!setup_pipeline (wl))
+  if (!setup_pipeline (self))
     {
       g_task_return_new_error (
           task,
@@ -542,19 +552,19 @@ pt_waveloader_load_async (PtWaveloader *wl,
     }
 
   /* setup message handler */
-  bus = gst_pipeline_get_bus (GST_PIPELINE (wl->priv->pipeline));
-  wl->priv->bus_watch_id = gst_bus_add_watch (bus, bus_handler, task);
+  bus = gst_pipeline_get_bus (GST_PIPELINE (priv->pipeline));
+  priv->bus_watch_id = gst_bus_add_watch (bus, bus_handler, task);
   gst_object_unref (bus);
 
   /* Run pipeline and start timeout for progress and cancellation.
    * Errors are reported on bus. */
-  gst_element_set_state (wl->priv->pipeline, GST_STATE_PLAYING);
-  wl->priv->progress_timeout = g_timeout_add (30, (GSourceFunc) check_progress, task);
+  gst_element_set_state (priv->pipeline, GST_STATE_PLAYING);
+  priv->progress_timeout = g_timeout_add (30, (GSourceFunc) check_progress, task);
 }
 
 /**
  * pt_waveloader_get_duration:
- * @wl: a #PtWaveloader
+ * @self: a #PtWaveloader
  *
  * Returns the duration of stream. As the whole stream is scanned, this is
  * supposed to be an exact duration, not an estimate.
@@ -564,14 +574,15 @@ pt_waveloader_load_async (PtWaveloader *wl,
  * Since: 1.4
  */
 gint64
-pt_waveloader_get_duration (PtWaveloader *wl)
+pt_waveloader_get_duration (PtWaveloader *self)
 {
-  return wl->priv->duration;
+  PtWaveloaderPrivate *priv = pt_waveloader_get_instance_private (self);
+  return priv->duration;
 }
 
 /**
  * pt_waveloader_resize_finish:
- * @wl: a #PtWaveloader
+ * @self: a #PtWaveloader
  * @result: the #GAsyncResult passed to your #GAsyncReadyCallback
  * @error: (nullable): a pointer to a NULL #GError, or NULL
  *
@@ -583,37 +594,39 @@ pt_waveloader_get_duration (PtWaveloader *wl)
  * Since: 2.0
  */
 gboolean
-pt_waveloader_resize_finish (PtWaveloader *wl,
+pt_waveloader_resize_finish (PtWaveloader *self,
                              GAsyncResult *result,
-                             GError **error)
+                             GError      **error)
 {
-  g_return_val_if_fail (g_task_is_valid (result, wl), FALSE);
+  g_return_val_if_fail (g_task_is_valid (result, self), FALSE);
 
-  wl->priv->data_pending = FALSE;
+  PtWaveloaderPrivate *priv = pt_waveloader_get_instance_private (self);
+  priv->data_pending = FALSE;
   return g_task_propagate_boolean (G_TASK (result), error);
 }
 
 static void
-pt_waveloader_resize_real (GTask *task,
-                           gpointer source_object,
-                           gpointer task_data,
+pt_waveloader_resize_real (GTask        *task,
+                           gpointer      source_object,
+                           gpointer      task_data,
                            GCancellable *cancellable)
 {
-  PtWaveloader *wl = source_object;
-  gint pps = GPOINTER_TO_INT (task_data);
-  gint lowres_len;
-  gint index_in = 0;
-  gint index_out = 0;
-  gboolean result = TRUE;
+  PtWaveloader        *self = source_object;
+  PtWaveloaderPrivate *priv = pt_waveloader_get_instance_private (self);
+  gint                 pps = GPOINTER_TO_INT (task_data);
+  gint                 lowres_len;
+  gint                 index_in = 0;
+  gint                 index_out = 0;
+  gboolean             result = TRUE;
 
-  lowres_len = calc_lowres_len (wl->priv->hires->len, pps);
-  if (wl->priv->lowres == NULL || wl->priv->lowres->len != lowres_len)
+  lowres_len = calc_lowres_len (priv->hires->len, pps);
+  if (priv->lowres == NULL || priv->lowres->len != lowres_len)
     {
-      g_array_set_size (wl->priv->lowres, lowres_len);
-      g_signal_emit_by_name (wl, "array-size-changed");
+      g_array_set_size (priv->lowres, lowres_len);
+      g_signal_emit_by_name (self, "array-size-changed");
     }
 
-  while (wl->priv->hires->len > index_in)
+  while (priv->hires->len > index_in)
     {
 
       if (g_cancellable_is_cancelled (cancellable))
@@ -622,15 +635,15 @@ pt_waveloader_resize_real (GTask *task,
           break;
         }
 
-      convert_one_second (wl->priv->hires,
-                          wl->priv->lowres,
+      convert_one_second (priv->hires,
+                          priv->lowres,
                           &index_in,
                           &index_out,
                           pps);
     }
 
   g_log_structured (G_LOG_DOMAIN, G_LOG_LEVEL_DEBUG,
-                    "MESSAGE", "hires->len: %d", wl->priv->hires->len);
+                    "MESSAGE", "hires->len: %d", priv->hires->len);
   g_log_structured (G_LOG_DOMAIN, G_LOG_LEVEL_DEBUG,
                     "MESSAGE", "Array size: %" G_GINT64_FORMAT " ",
                     lowres_len);
@@ -649,7 +662,7 @@ pt_waveloader_resize_real (GTask *task,
 
 /**
  * pt_waveloader_resize_async:
- * @wl: a #PtWaveloader
+ * @self: a #PtWaveloader
  * @pps: the requested pixel per second ratio
  * @cancellable: (nullable): a #GCancellable or NULL
  * @callback: (scope async): a #GAsyncReadyCallback to call when the operation is complete
@@ -677,19 +690,20 @@ pt_waveloader_resize_real (GTask *task,
  * Since: 2.0
  */
 void
-pt_waveloader_resize_async (PtWaveloader *wl,
-                            gint pps,
-                            GCancellable *cancellable,
+pt_waveloader_resize_async (PtWaveloader       *self,
+                            gint                pps,
+                            GCancellable       *cancellable,
                             GAsyncReadyCallback callback,
-                            gpointer user_data)
+                            gpointer            user_data)
 {
-  g_return_if_fail (PT_IS_WAVELOADER (wl));
+  g_return_if_fail (PT_IS_WAVELOADER (self));
   g_return_if_fail ((pps >= 25) && (pps <= 200));
 
-  GTask *task;
+  PtWaveloaderPrivate *priv = pt_waveloader_get_instance_private (self);
+  GTask               *task;
 
-  task = g_task_new (wl, cancellable, callback, user_data);
-  if (wl->priv->hires->len == 0)
+  task = g_task_new (self, cancellable, callback, user_data);
+  if (priv->hires->len == 0)
     {
       g_task_return_new_error (
           task,
@@ -701,7 +715,7 @@ pt_waveloader_resize_async (PtWaveloader *wl,
       g_object_unref (task);
       return;
     }
-  if (wl->priv->load_pending || wl->priv->data_pending)
+  if (priv->load_pending || priv->data_pending)
     {
       g_task_return_new_error (
           task,
@@ -714,7 +728,7 @@ pt_waveloader_resize_async (PtWaveloader *wl,
       return;
     }
 
-  wl->priv->data_pending = TRUE;
+  priv->data_pending = TRUE;
   g_task_set_task_data (task, GINT_TO_POINTER (pps), NULL);
   g_task_run_in_thread (task, pt_waveloader_resize_real);
   g_object_unref (task);
@@ -723,13 +737,13 @@ pt_waveloader_resize_async (PtWaveloader *wl,
 typedef struct
 {
   GAsyncResult *res;
-  GMainLoop *loop;
+  GMainLoop    *loop;
 } SyncData;
 
 static void
-quit_loop_cb (PtWaveloader *wl,
+quit_loop_cb (PtWaveloader *self,
               GAsyncResult *res,
-              gpointer user_data)
+              gpointer      user_data)
 {
   SyncData *data = user_data;
   data->res = g_object_ref (res);
@@ -738,7 +752,7 @@ quit_loop_cb (PtWaveloader *wl,
 
 /**
  * pt_waveloader_resize:
- * @wl: a #PtWaveloader
+ * @self: a #PtWaveloader
  * @pps: the requested pixel per second ratio
  * @error: (nullable): return location for an error, or NULL
  *
@@ -749,16 +763,16 @@ quit_loop_cb (PtWaveloader *wl,
  * Since: 2.0
  */
 gboolean
-pt_waveloader_resize (PtWaveloader *wl,
-                      gint pps,
-                      GError **error)
+pt_waveloader_resize (PtWaveloader *self,
+                      gint          pps,
+                      GError      **error)
 {
-  g_return_val_if_fail (PT_IS_WAVELOADER (wl), FALSE);
+  g_return_val_if_fail (PT_IS_WAVELOADER (self), FALSE);
   g_return_val_if_fail ((pps >= 25) && (pps <= 200), FALSE);
   g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
 
-  gboolean result;
-  SyncData data;
+  gboolean      result;
+  SyncData      data;
   GMainContext *context;
 
   /* Note: If done in the default thread, all sorts of bad things happen,
@@ -770,10 +784,10 @@ pt_waveloader_resize (PtWaveloader *wl,
   data.loop = g_main_loop_new (context, FALSE);
   data.res = NULL;
 
-  pt_waveloader_resize_async (wl, pps, NULL, (GAsyncReadyCallback) quit_loop_cb, &data);
+  pt_waveloader_resize_async (self, pps, NULL, (GAsyncReadyCallback) quit_loop_cb, &data);
   g_main_loop_run (data.loop);
 
-  result = pt_waveloader_resize_finish (wl, data.res, error);
+  result = pt_waveloader_resize_finish (self, data.res, error);
 
   g_main_context_pop_thread_default (context);
   g_main_context_unref (context);
@@ -785,7 +799,7 @@ pt_waveloader_resize (PtWaveloader *wl,
 
 /**
  * pt_waveloader_get_data:
- * @wl: a #PtWaveloader
+ * @self: a #PtWaveloader
  *
  * This returns the pointer to a GArray that is holding all the wave form data.
  * It consists of a minimum value in the range of -1 to 0 and a maximum value
@@ -799,16 +813,17 @@ pt_waveloader_resize (PtWaveloader *wl,
  * Since: 2.0
  */
 GArray *
-pt_waveloader_get_data (PtWaveloader *wl)
+pt_waveloader_get_data (PtWaveloader *self)
 {
-  return wl->priv->lowres;
+  PtWaveloaderPrivate *priv = pt_waveloader_get_instance_private (self);
+  return priv->lowres;
 }
 /* --------------------- Init and GObject management ------------------------ */
 
 static void
-pt_waveloader_init (PtWaveloader *wl)
+pt_waveloader_init (PtWaveloader *self)
 {
-  wl->priv = pt_waveloader_get_instance_private (wl);
+  PtWaveloaderPrivate *priv = pt_waveloader_get_instance_private (self);
 
   GError *gst_error = NULL;
   gst_init_check (NULL, NULL, &gst_error);
@@ -819,61 +834,61 @@ pt_waveloader_init (PtWaveloader *wl)
       g_clear_error (&gst_error);
     }
 
-  wl->priv->pipeline = NULL;
-  wl->priv->uri = NULL;
-  wl->priv->hires = g_array_new (FALSE, /* zero terminated */
-                                 TRUE,  /* clear to zero   */
-                                 sizeof (gint16));
-  wl->priv->lowres = g_array_new (FALSE, TRUE, sizeof (float));
-  wl->priv->bus_watch_id = 0;
-  wl->priv->progress_timeout = 0;
-  wl->priv->load_pending = FALSE;
-  wl->priv->data_pending = FALSE;
+  priv->pipeline = NULL;
+  priv->uri = NULL;
+  priv->hires = g_array_new (FALSE, /* zero terminated */
+                             TRUE,  /* clear to zero   */
+                             sizeof (gint16));
+  priv->lowres = g_array_new (FALSE, TRUE, sizeof (float));
+  priv->bus_watch_id = 0;
+  priv->progress_timeout = 0;
+  priv->load_pending = FALSE;
+  priv->data_pending = FALSE;
 }
 
 static void
 pt_waveloader_dispose (GObject *object)
 {
-  PtWaveloader *wl;
-  wl = PT_WAVELOADER (object);
+  PtWaveloader        *self = PT_WAVELOADER (object);
+  PtWaveloaderPrivate *priv = pt_waveloader_get_instance_private (self);
 
-  g_free (wl->priv->uri);
+  g_free (priv->uri);
 
-  g_array_unref (wl->priv->hires);
-  g_array_unref (wl->priv->lowres);
+  g_array_unref (priv->hires);
+  g_array_unref (priv->lowres);
 
-  if (wl->priv->bus_watch_id > 0)
+  if (priv->bus_watch_id > 0)
     {
-      g_source_remove (wl->priv->bus_watch_id);
-      wl->priv->bus_watch_id = 0;
+      g_source_remove (priv->bus_watch_id);
+      priv->bus_watch_id = 0;
     }
 
-  remove_timeout (wl);
+  remove_timeout (self);
 
-  if (wl->priv->pipeline)
+  if (priv->pipeline)
     {
-      gst_element_set_state (wl->priv->pipeline, GST_STATE_NULL);
-      gst_object_unref (GST_OBJECT (wl->priv->pipeline));
-      wl->priv->pipeline = NULL;
+      gst_element_set_state (priv->pipeline, GST_STATE_NULL);
+      gst_object_unref (GST_OBJECT (priv->pipeline));
+      priv->pipeline = NULL;
     }
 
   G_OBJECT_CLASS (pt_waveloader_parent_class)->dispose (object);
 }
 
 static void
-pt_waveloader_set_property (GObject *object,
-                            guint property_id,
+pt_waveloader_set_property (GObject      *object,
+                            guint         property_id,
                             const GValue *value,
-                            GParamSpec *pspec)
+                            GParamSpec   *pspec)
 {
-  PtWaveloader *wl;
-  wl = PT_WAVELOADER (object);
+  PtWaveloader        *self = PT_WAVELOADER (object);
+  PtWaveloaderPrivate *priv = pt_waveloader_get_instance_private (self);
 
   switch (property_id)
     {
     case PROP_URI:
-      g_free (wl->priv->uri);
-      wl->priv->uri = g_value_dup_string (value);
+      g_free (priv->uri);
+      priv->uri = g_value_dup_string (value);
       break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -882,18 +897,18 @@ pt_waveloader_set_property (GObject *object,
 }
 
 static void
-pt_waveloader_get_property (GObject *object,
-                            guint property_id,
-                            GValue *value,
+pt_waveloader_get_property (GObject    *object,
+                            guint       property_id,
+                            GValue     *value,
                             GParamSpec *pspec)
 {
-  PtWaveloader *wl;
-  wl = PT_WAVELOADER (object);
+  PtWaveloader        *self = PT_WAVELOADER (object);
+  PtWaveloaderPrivate *priv = pt_waveloader_get_instance_private (self);
 
   switch (property_id)
     {
     case PROP_URI:
-      g_value_set_string (value, wl->priv->uri);
+      g_value_set_string (value, priv->uri);
       break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -910,7 +925,7 @@ pt_waveloader_class_init (PtWaveloaderClass *klass)
 
   /**
    * PtWaveloader::progress:
-   * @wl: the waveloader emitting the signal
+   * @self: the waveloader emitting the signal
    * @progress: the new progress state, ranging from 0.0 to 1.0
    *
    * While loading a waveform a progress signal is emitted,
@@ -931,7 +946,7 @@ pt_waveloader_class_init (PtWaveloaderClass *klass)
 
   /**
    * PtWaveloader::array-size-changed:
-   * @wl: the waveloader emitting the signal
+   * @self: the waveloader emitting the signal
    *
    * The size of the array with waveform data has changed.
    */
@@ -953,11 +968,9 @@ pt_waveloader_class_init (PtWaveloaderClass *klass)
    */
   obj_properties[PROP_URI] =
       g_param_spec_string (
-          "uri",
-          "URI to load from",
-          "URI to load from",
+          "uri", NULL, NULL,
           "",
-          G_PARAM_READWRITE | G_PARAM_CONSTRUCT);
+          G_PARAM_READWRITE | G_PARAM_CONSTRUCT | G_PARAM_STATIC_STRINGS);
 
   g_object_class_install_properties (
       G_OBJECT_CLASS (klass),
