@@ -1,4 +1,4 @@
-/* Copyright (C) 2017, 2020 Gabor Karsay <gabor.karsay@gmx.at>
+/* Copyright 2017 Gabor Karsay <gabor.karsay@gmx.at>
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as published
@@ -42,35 +42,39 @@
  */
 
 #include "config.h"
-#include "pt-waveviewer.h"
+
 #include "pt-waveviewer-cursor.h"
 
+#include "pt-waveviewer.h"
+
 #define MARKER_BOX_W 10
 #define MARKER_BOX_H 8
 
-struct _PtWaveviewerCursorPrivate
+struct _PtWaveviewerCursor
 {
+  GtkDrawingArea parent;
+
   cairo_surface_t *cursor;
-  GdkRGBA cursor_color;
-  gint position;
+  GdkRGBA          cursor_color;
+  gint             position;
 };
 
-G_DEFINE_TYPE_WITH_PRIVATE (PtWaveviewerCursor, pt_waveviewer_cursor, GTK_TYPE_DRAWING_AREA);
+G_DEFINE_TYPE (PtWaveviewerCursor, pt_waveviewer_cursor, GTK_TYPE_DRAWING_AREA);
 
 static void
 pt_waveviewer_cursor_draw (GtkDrawingArea *widget,
-                           cairo_t *cr,
-                           int content_width,
-                           int content_height,
-                           gpointer user_data)
+                           cairo_t        *cr,
+                           int             content_width,
+                           int             content_height,
+                           gpointer        user_data)
 {
   PtWaveviewerCursor *self = (PtWaveviewerCursor *) widget;
 
-  if (self->priv->position == -1)
+  if (self->position == -1)
     return;
 
-  cairo_set_source_surface (cr, self->priv->cursor,
-                            self->priv->position - MARKER_BOX_W / 2, 0);
+  cairo_set_source_surface (cr, self->cursor,
+                            self->position - MARKER_BOX_W / 2, 0);
   cairo_paint (cr);
 }
 
@@ -80,23 +84,25 @@ cache_cursor (PtWaveviewerCursor *self)
   if (!gtk_widget_get_realized (GTK_WIDGET (self)))
     return;
 
-  if (self->priv->cursor)
-    cairo_surface_destroy (self->priv->cursor);
+  if (self->cursor)
+    cairo_surface_destroy (self->cursor);
 
-  cairo_t *cr;
-  gint height = gtk_widget_get_allocated_height (GTK_WIDGET (self));
-  GtkNative *native;
+  cairo_t    *cr;
+  gint        height = gtk_widget_get_height (GTK_WIDGET (self));
+  GtkNative  *native;
   GdkSurface *surface;
+  gint        scale;
 
   native = gtk_widget_get_native (GTK_WIDGET (self));
   surface = gtk_native_get_surface (native);
-  self->priv->cursor = gdk_surface_create_similar_surface (surface,
-                                                           CAIRO_CONTENT_COLOR_ALPHA,
-                                                           MARKER_BOX_W,
-                                                           height);
-  cr = cairo_create (self->priv->cursor);
+  scale = gdk_surface_get_scale (surface);
+  self->cursor = cairo_image_surface_create (CAIRO_FORMAT_ARGB32,
+                                             MARKER_BOX_W * scale,
+                                             height * scale);
+  cairo_surface_set_device_scale (self->cursor, scale, scale);
+  cr = cairo_create (self->cursor);
 
-  gdk_cairo_set_source_rgba (cr, &self->priv->cursor_color);
+  gdk_cairo_set_source_rgba (cr, &self->cursor_color);
 
   cairo_move_to (cr, 0 + MARKER_BOX_W / 2, height);
   cairo_line_to (cr, 0 + MARKER_BOX_W / 2, 0);
@@ -112,9 +118,9 @@ cache_cursor (PtWaveviewerCursor *self)
 
 static void
 pt_waveviewer_cursor_size_allocate (GtkWidget *widget,
-                                    gint width,
-                                    gint height,
-                                    gint baseline)
+                                    gint       width,
+                                    gint       height,
+                                    gint       baseline)
 {
   GTK_WIDGET_CLASS (pt_waveviewer_cursor_parent_class)->size_allocate (widget, width, height, baseline);
 
@@ -125,18 +131,12 @@ pt_waveviewer_cursor_size_allocate (GtkWidget *widget,
 static void
 update_cached_style_values (PtWaveviewerCursor *self)
 {
-  /* Update color */
-
-  GtkStyleContext *context;
-
-  context = gtk_widget_get_style_context (GTK_WIDGET (self));
-  gtk_style_context_get_color (context, &self->priv->cursor_color);
-
+  gtk_widget_get_color (GTK_WIDGET (self), &self->cursor_color);
   cache_cursor (self);
 }
 
 static void
-pt_waveviewer_cursor_state_flags_changed (GtkWidget *widget,
+pt_waveviewer_cursor_state_flags_changed (GtkWidget    *widget,
                                           GtkStateFlags flags)
 {
   update_cached_style_values (PT_WAVEVIEWER_CURSOR (widget));
@@ -152,32 +152,26 @@ pt_waveviewer_cursor_realize (GtkWidget *widget)
 
 void
 pt_waveviewer_cursor_render (PtWaveviewerCursor *self,
-                             gint position)
+                             gint                position)
 {
   gint width;
 
-  width = gtk_widget_get_allocated_width (GTK_WIDGET (self));
+  width = gtk_widget_get_width (GTK_WIDGET (self));
   position = CLAMP (position, -1, width + MARKER_BOX_W);
 
-  if (self->priv->position == position)
+  if (self->position == position)
     return;
 
-  self->priv->position = position;
+  self->position = position;
   gtk_widget_queue_draw (GTK_WIDGET (self));
 }
 
 static void
 pt_waveviewer_cursor_init (PtWaveviewerCursor *self)
 {
-  self->priv = pt_waveviewer_cursor_get_instance_private (self);
-
-  GtkStyleContext *context;
-
-  self->priv->cursor = NULL;
-  self->priv->position = -1;
-
-  context = gtk_widget_get_style_context (GTK_WIDGET (self));
-  gtk_style_context_add_class (context, "cursor");
+  self->cursor = NULL;
+  self->position = -1;
+  gtk_widget_add_css_class (GTK_WIDGET (self), "cursor");
 
   gtk_drawing_area_set_draw_func (GTK_DRAWING_AREA (self), pt_waveviewer_cursor_draw, NULL, NULL);
 }
@@ -187,8 +181,8 @@ pt_waveviewer_cursor_finalize (GObject *object)
 {
   PtWaveviewerCursor *self = PT_WAVEVIEWER_CURSOR (object);
 
-  if (self->priv->cursor)
-    cairo_surface_destroy (self->priv->cursor);
+  if (self->cursor)
+    cairo_surface_destroy (self->cursor);
 
   G_OBJECT_CLASS (pt_waveviewer_cursor_parent_class)->finalize (object);
 }
@@ -196,7 +190,7 @@ pt_waveviewer_cursor_finalize (GObject *object)
 static void
 pt_waveviewer_cursor_class_init (PtWaveviewerCursorClass *klass)
 {
-  GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
+  GObjectClass   *gobject_class = G_OBJECT_CLASS (klass);
   GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
 
   gobject_class->finalize = pt_waveviewer_cursor_finalize;
