@@ -1,4 +1,4 @@
-/* Copyright (C) 2020 Gabor Karsay <gabor.karsay@gmx.at>
+/* Copyright 2020 Gabor Karsay <gabor.karsay@gmx.at>
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as published
@@ -40,68 +40,72 @@
  */
 
 #include "config.h"
-#include "pt-waveviewer.h"
+
 #include "pt-waveviewer-scrollbox.h"
 
-struct _PtWaveviewerScrollboxPrivate
+#include "pt-waveviewer.h"
+
+struct _PtWaveviewerScrollbox
 {
-  GdkPaintable *paintable;
+  GtkBox parent;
+
+  GdkPaintable  *paintable;
   GtkAdjustment *adjustment;
-  guint hscroll_policy : 1;
-  gint fake_width;
+  guint          hscroll_policy : 1;
+  gint           fake_width;
 };
 
 enum
 {
-  PROP_0,
-  PROP_HADJUSTMENT,
+  PROP_HADJUSTMENT = 1,
   PROP_VADJUSTMENT,
   PROP_HSCROLL_POLICY,
   PROP_VSCROLL_POLICY
 };
 
-G_DEFINE_TYPE_WITH_CODE (PtWaveviewerScrollbox, pt_waveviewer_scrollbox, GTK_TYPE_BOX, G_ADD_PRIVATE (PtWaveviewerScrollbox) G_IMPLEMENT_INTERFACE (GTK_TYPE_SCROLLABLE, NULL));
+G_DEFINE_TYPE_WITH_CODE (PtWaveviewerScrollbox, pt_waveviewer_scrollbox, GTK_TYPE_BOX, G_IMPLEMENT_INTERFACE (GTK_TYPE_SCROLLABLE, NULL));
 
 static void
 pt_waveviewer_scrollbox_set_adjustment_values (PtWaveviewerScrollbox *self)
 {
   /* Set values depending on waveform array size */
 
-  GtkAllocation allocation;
-  GtkAdjustment *adj = self->priv->adjustment;
+  GtkAdjustment *adj = self->adjustment;
+  gint           width, max;
 
-  gtk_widget_get_allocation (GTK_WIDGET (self), &allocation);
+  width = gtk_widget_get_width (GTK_WIDGET (self));
+  max = MAX (self->fake_width, width);
 
   gtk_adjustment_configure (adj,
                             gtk_adjustment_get_value (adj),
-                            0.0,
-                            MAX (self->priv->fake_width, allocation.width),
-                            allocation.width * 0.2,
-                            allocation.width * 0.9,
-                            allocation.width);
+                            0.0,         /* lower */
+                            max,         /* upper */
+                            width * 0.2, /* step increment */
+                            width * 0.9, /* page increment */
+                            width);      /* page size */
 }
 
 static void
 scrollbox_set_adjustment (PtWaveviewerScrollbox *self,
-                          GtkAdjustment *adjustment)
+                          GtkAdjustment         *adjustment)
 {
-  if (adjustment && self->priv->adjustment == adjustment)
+  if (adjustment && self->adjustment == adjustment)
     /* same pointer or both NULL */
     return;
 
-  if (self->priv->adjustment != NULL)
+  if (self->adjustment != NULL)
     {
       g_signal_handlers_disconnect_matched (
-          self->priv->adjustment,
+          self->adjustment,
           G_SIGNAL_MATCH_DATA,
           0, 0, NULL, NULL, self);
-      g_object_unref (self->priv->adjustment);
+      g_object_unref (self->adjustment);
     }
 
   if (!adjustment)
     adjustment = gtk_adjustment_new (0.0, 0.0, 0.0, 0.0, 0.0, 0.0);
 
-  self->priv->adjustment = g_object_ref_sink (adjustment);
+  self->adjustment = g_object_ref_sink (adjustment);
 
   pt_waveviewer_scrollbox_set_adjustment_values (self);
 
@@ -110,15 +114,15 @@ scrollbox_set_adjustment (PtWaveviewerScrollbox *self,
 
 void
 pt_waveviewer_scrollbox_set (PtWaveviewerScrollbox *self,
-                             gint width)
+                             gint                   width)
 {
-  self->priv->fake_width = width;
+  self->fake_width = width;
   pt_waveviewer_scrollbox_set_adjustment_values (self);
 }
 
 static void
 invalidate_size_cb (GdkPaintable *paintable,
-                    gpointer user_data)
+                    gpointer      user_data)
 {
   PtWaveviewerScrollbox *self = PT_WAVEVIEWER_SCROLLBOX (user_data);
   pt_waveviewer_scrollbox_set_adjustment_values (self);
@@ -133,24 +137,23 @@ pt_waveviewer_scrollbox_realize (GtkWidget *widget)
 }
 
 static void
-pt_waveviewer_scrollbox_get_property (GObject *object,
-                                      guint property_id,
-                                      GValue *value,
+pt_waveviewer_scrollbox_get_property (GObject    *object,
+                                      guint       property_id,
+                                      GValue     *value,
                                       GParamSpec *pspec)
 {
   PtWaveviewerScrollbox *self = PT_WAVEVIEWER_SCROLLBOX (object);
-  PtWaveviewerScrollboxPrivate *priv = self->priv;
 
   switch (property_id)
     {
     case PROP_HADJUSTMENT:
-      g_value_set_object (value, priv->adjustment);
+      g_value_set_object (value, self->adjustment);
       break;
     case PROP_VADJUSTMENT:
       g_value_set_object (value, NULL);
       break;
     case PROP_HSCROLL_POLICY:
-      g_value_set_enum (value, priv->hscroll_policy);
+      g_value_set_enum (value, self->hscroll_policy);
       break;
     case PROP_VSCROLL_POLICY:
       g_value_set_enum (value, 1);
@@ -162,13 +165,12 @@ pt_waveviewer_scrollbox_get_property (GObject *object,
 }
 
 static void
-pt_waveviewer_scrollbox_set_property (GObject *object,
-                                      guint property_id,
+pt_waveviewer_scrollbox_set_property (GObject      *object,
+                                      guint         property_id,
                                       const GValue *value,
-                                      GParamSpec *pspec)
+                                      GParamSpec   *pspec)
 {
   PtWaveviewerScrollbox *self = PT_WAVEVIEWER_SCROLLBOX (object);
-  PtWaveviewerScrollboxPrivate *priv = self->priv;
 
   switch (property_id)
     {
@@ -179,9 +181,9 @@ pt_waveviewer_scrollbox_set_property (GObject *object,
       /* there is no vadjustment */
       break;
     case PROP_HSCROLL_POLICY:
-      if (priv->hscroll_policy != g_value_get_enum (value))
+      if (self->hscroll_policy != g_value_get_enum (value))
         {
-          priv->hscroll_policy = g_value_get_enum (value);
+          self->hscroll_policy = g_value_get_enum (value);
           gtk_widget_queue_resize (GTK_WIDGET (self));
           g_object_notify_by_pspec (object, pspec);
         }
@@ -199,10 +201,9 @@ static void
 pt_waveviewer_scrollbox_dispose (GObject *object)
 {
   PtWaveviewerScrollbox *self = PT_WAVEVIEWER_SCROLLBOX (object);
-  PtWaveviewerScrollboxPrivate *priv = self->priv;
 
-  g_clear_object (&priv->paintable);
-  g_clear_object (&priv->adjustment);
+  g_clear_object (&self->paintable);
+  g_clear_object (&self->adjustment);
 
   G_OBJECT_CLASS (pt_waveviewer_scrollbox_parent_class)->dispose (object);
 }
@@ -210,14 +211,12 @@ pt_waveviewer_scrollbox_dispose (GObject *object)
 static void
 pt_waveviewer_scrollbox_init (PtWaveviewerScrollbox *self)
 {
-  self->priv = pt_waveviewer_scrollbox_get_instance_private (self);
-
-  self->priv->adjustment = NULL;
-  self->priv->fake_width = 0;
+  self->adjustment = NULL;
+  self->fake_width = 0;
 
   /* watch size changes with a GdkPaintable */
-  self->priv->paintable = gtk_widget_paintable_new (GTK_WIDGET (self));
-  g_signal_connect (self->priv->paintable, "invalidate-size",
+  self->paintable = gtk_widget_paintable_new (GTK_WIDGET (self));
+  g_signal_connect (self->paintable, "invalidate-size",
                     G_CALLBACK (invalidate_size_cb), self);
 
   gtk_widget_set_name (GTK_WIDGET (self), "scrollbox");
@@ -227,7 +226,7 @@ static void
 pt_waveviewer_scrollbox_class_init (PtWaveviewerScrollboxClass *klass)
 {
   GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
-  GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
+  GObjectClass   *gobject_class = G_OBJECT_CLASS (klass);
 
   gobject_class->set_property = pt_waveviewer_scrollbox_set_property;
   gobject_class->get_property = pt_waveviewer_scrollbox_get_property;
