@@ -1,4 +1,4 @@
-/* Copyright (C) 2017, 2020 Gabor Karsay <gabor.karsay@gmx.at>
+/* Copyright 2017 Gabor Karsay <gabor.karsay@gmx.at>
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as published
@@ -39,11 +39,15 @@
  */
 
 #include "config.h"
-#include "pt-waveviewer.h"
+
 #include "pt-waveviewer-waveform.h"
 
-struct _PtWaveviewerWaveformPrivate
+#include "pt-waveviewer.h"
+
+struct _PtWaveviewerWaveform
 {
+  GtkDrawingArea parent;
+
   /* Wavedata */
   GArray *peaks;
 
@@ -53,11 +57,11 @@ struct _PtWaveviewerWaveformPrivate
   GdkRGBA wave_color;
 };
 
-G_DEFINE_TYPE_WITH_PRIVATE (PtWaveviewerWaveform, pt_waveviewer_waveform, GTK_TYPE_DRAWING_AREA);
+G_DEFINE_TYPE (PtWaveviewerWaveform, pt_waveviewer_waveform, GTK_TYPE_DRAWING_AREA);
 
 static gint64
 pixel_to_array (PtWaveviewerWaveform *self,
-                gint64 pixel)
+                gint64                pixel)
 {
   /* Convert a position in the drawing area to an index in the peaks array.
      The returned index is the peak’s min value, +1 is the max value.
@@ -66,39 +70,34 @@ pixel_to_array (PtWaveviewerWaveform *self,
   gint64 result;
 
   result = pixel * 2;
-  if (result + 1 >= self->priv->peaks->len)
+  if (result + 1 >= self->peaks->len)
     result = -1;
 
   return result;
 }
 
 static void
-pt_waveviewer_waveform_snapshot (GtkWidget *widget,
+pt_waveviewer_waveform_snapshot (GtkWidget   *widget,
                                  GtkSnapshot *snapshot)
 {
   PtWaveviewerWaveform *self = (PtWaveviewerWaveform *) widget;
 
-  GArray *peaks = self->priv->peaks;
-  GtkStyleContext *context;
-  gint pixel;
-  gint array;
+  GArray *peaks = self->peaks;
+  gint    pixel;
+  gint    array;
   gdouble min, max;
-  gint width, height, offset;
-  gint half, middle;
+  gint    width, height, offset;
+  gint    half, middle;
 
-  context = gtk_widget_get_style_context (GTK_WIDGET (widget));
-  height = gtk_widget_get_allocated_height (GTK_WIDGET (widget));
-  width = gtk_widget_get_allocated_width (GTK_WIDGET (widget));
-
-  gtk_style_context_get_color (context, &self->priv->wave_color);
-  gtk_snapshot_render_background (snapshot, context,
-                                  0, 0,
-                                  width, height);
   if (peaks == NULL || peaks->len == 0)
     return;
 
+  height = gtk_widget_get_height (GTK_WIDGET (widget));
+  width = gtk_widget_get_width (GTK_WIDGET (widget));
+  gtk_widget_get_color (widget, &self->wave_color);
+
   /* paint waveform */
-  offset = (gint) gtk_adjustment_get_value (self->priv->adj);
+  offset = (gint) gtk_adjustment_get_value (self->adj);
   half = height / 2 - 1;
   middle = height / 2;
   for (pixel = 0; pixel <= width; pixel += 1)
@@ -108,7 +107,7 @@ pt_waveviewer_waveform_snapshot (GtkWidget *widget,
         break;
       min = (middle + half * g_array_index (peaks, float, array) * -1);
       max = (middle - half * g_array_index (peaks, float, array + 1));
-      gtk_snapshot_append_color (snapshot, &self->priv->wave_color,
+      gtk_snapshot_append_color (snapshot, &self->wave_color,
                                  &GRAPHENE_RECT_INIT (pixel, max, 1, min - max));
     }
 }
@@ -116,16 +115,11 @@ pt_waveviewer_waveform_snapshot (GtkWidget *widget,
 static void
 update_cached_style_values (PtWaveviewerWaveform *self)
 {
-  /* Update color */
-
-  GtkStyleContext *context;
-
-  context = gtk_widget_get_style_context (GTK_WIDGET (self));
-  gtk_style_context_get_color (context, &self->priv->wave_color);
+  gtk_widget_get_color (GTK_WIDGET (self), &self->wave_color);
 }
 
 static void
-pt_waveviewer_waveform_state_flags_changed (GtkWidget *widget,
+pt_waveviewer_waveform_state_flags_changed (GtkWidget    *widget,
                                             GtkStateFlags flags)
 {
   update_cached_style_values (PT_WAVEVIEWER_WAVEFORM (widget));
@@ -141,15 +135,15 @@ pt_waveviewer_waveform_realize (GtkWidget *widget)
 
 void
 pt_waveviewer_waveform_set (PtWaveviewerWaveform *self,
-                            GArray *peaks)
+                            GArray               *peaks)
 {
-  self->priv->peaks = peaks;
+  self->peaks = peaks;
   gtk_widget_queue_draw (GTK_WIDGET (self));
 }
 
 static void
 adj_value_changed (GtkAdjustment *adj,
-                   gpointer data)
+                   gpointer       data)
 {
   PtWaveviewerWaveform *self = PT_WAVEVIEWER_WAVEFORM (data);
   gtk_widget_queue_draw (GTK_WIDGET (self));
@@ -160,7 +154,7 @@ pt_waveviewer_waveform_root (GtkWidget *widget)
 {
   PtWaveviewerWaveform *self = PT_WAVEVIEWER_WAVEFORM (widget);
 
-  if (self->priv->adj)
+  if (self->adj)
     return;
 
   /* Get parent’s GtkAdjustment */
@@ -168,22 +162,16 @@ pt_waveviewer_waveform_root (GtkWidget *widget)
   parent = gtk_widget_get_ancestor (widget, GTK_TYPE_SCROLLED_WINDOW);
   if (parent)
     {
-      self->priv->adj = gtk_scrolled_window_get_hadjustment (GTK_SCROLLED_WINDOW (parent));
-      g_signal_connect (self->priv->adj, "value-changed", G_CALLBACK (adj_value_changed), self);
+      self->adj = gtk_scrolled_window_get_hadjustment (GTK_SCROLLED_WINDOW (parent));
+      g_signal_connect (self->adj, "value-changed", G_CALLBACK (adj_value_changed), self);
     }
 }
 
 static void
 pt_waveviewer_waveform_init (PtWaveviewerWaveform *self)
 {
-  self->priv = pt_waveviewer_waveform_get_instance_private (self);
-
-  GtkStyleContext *context;
-
-  self->priv->peaks = NULL;
-
-  context = gtk_widget_get_style_context (GTK_WIDGET (self));
-  gtk_style_context_add_class (context, "view");
+  self->peaks = NULL;
+  gtk_widget_add_css_class (GTK_WIDGET (self), "view");
 }
 
 static void
