@@ -1,4 +1,4 @@
-/* Copyright (C) Gabor Karsay 2020 <gabor.karsay@gmx.at>
+/* Copyright 2020 Gabor Karsay <gabor.karsay@gmx.at>
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as published
@@ -15,10 +15,12 @@
  */
 
 #include "config.h"
+
 #include "gst/gstptaudioasrbin.h"
 #include "gst/gstptaudiobin.h"
 #include "gst/gstptaudioplaybin.h"
 #include "mock-plugin.h"
+
 #include <glib.h>
 #include <gst/audio/streamvolume.h>
 #include <gst/gst.h>
@@ -28,13 +30,13 @@
 typedef struct
 {
   GAsyncResult *res;
-  GMainLoop *loop;
+  GMainLoop    *loop;
 } SyncData;
 
 static SyncData
 create_sync_data (void)
 {
-  SyncData data;
+  SyncData      data;
   GMainContext *context;
 
   context = g_main_context_default ();
@@ -53,8 +55,8 @@ free_sync_data (SyncData data)
 
 static void
 quit_loop_cb (GstPtAudioAsrBin *bin,
-              GAsyncResult *res,
-              gpointer user_data)
+              GAsyncResult     *res,
+              gpointer          user_data)
 {
   SyncData *data = user_data;
   data->res = g_object_ref (res);
@@ -68,12 +70,12 @@ gst_audioasrbin (void)
 {
 
   GstPtAudioAsrBin *asr;
-  PtConfig *good, *bad;
-  GFile *testfile;
-  gchar *testpath;
-  GError *error = NULL;
-  gboolean success;
-  SyncData data;
+  PtConfig         *good, *bad;
+  GFile            *testfile;
+  gchar            *testpath;
+  GError           *error = NULL;
+  gboolean          success;
+  SyncData          data;
 
   /* Create config with existing plugin */
   testpath = g_test_build_filename (G_TEST_DIST, "data", "config-mock-plugin.asr", NULL);
@@ -94,7 +96,7 @@ gst_audioasrbin (void)
   /* Create Test-Element */
   asr = GST_PT_AUDIO_ASR_BIN (gst_element_factory_make ("ptaudioasrbin", "testbin"));
   g_assert_nonnull (asr);
-  g_assert_false (asr->is_configured);
+  g_assert_false (gst_pt_audio_asr_bin_is_configured (asr));
 
   /* Apply existing plugin */
   data = create_sync_data ();
@@ -103,7 +105,6 @@ gst_audioasrbin (void)
   success = gst_pt_audio_asr_bin_configure_asr_finish (asr, data.res, &error);
   g_assert_true (success);
   g_assert_no_error (error);
-  g_assert_true (asr->is_configured);
   g_assert_true (gst_pt_audio_asr_bin_is_configured (asr));
   free_sync_data (data);
 
@@ -114,7 +115,6 @@ gst_audioasrbin (void)
   success = gst_pt_audio_asr_bin_configure_asr_finish (asr, data.res, &error);
   g_assert_false (success);
   g_assert_error (error, GST_CORE_ERROR, GST_CORE_ERROR_MISSING_PLUGIN);
-  g_assert_false (asr->is_configured);
   g_assert_false (gst_pt_audio_asr_bin_is_configured (asr));
   g_clear_error (&error);
   free_sync_data (data);
@@ -132,7 +132,7 @@ main (int argc, char *argv[])
   gst_pt_audio_asr_bin_register ();
   gst_pt_audio_play_bin_register ();
   gst_pt_audio_bin_register ();
-  mock_plugin_register ();
+  pt_mock_plugin_register ();
 
   g_test_add_func ("/gst/audioasrbin_new", gst_audioasrbin);
 
