@@ -1,4 +1,4 @@
-/* Copyright (C) Gabor Karsay 2016, 2019 <gabor.karsay@gmx.at>
+/* Copyright 2016 Gabor Karsay <gabor.karsay@gmx.at>
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as published
@@ -14,35 +14,11 @@
  * with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef PT_APP_H
-#define PT_APP_H
+#pragma once
 
-#include "config.h"
-#include <gtk/gtk.h>
+#include <adwaita.h>
 
 #define PT_APP_TYPE (pt_app_get_type ())
-#define PT_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PT_APP_TYPE, PtApp))
-#define PT_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PT_APP_TYPE))
-
-typedef struct _PtApp PtApp;
-typedef struct _PtAppClass PtAppClass;
-typedef struct _PtAppPrivate PtAppPrivate;
-
-struct _PtApp
-{
-  GtkApplication parent;
-
-  /*< private > */
-  PtAppPrivate *priv;
-};
-
-struct _PtAppClass
-{
-  GtkApplicationClass parent_class;
-};
-
-GType pt_app_get_type (void) G_GNUC_CONST;
+G_DECLARE_FINAL_TYPE (PtApp, pt_app, PT, APP, AdwApplication)
 
 PtApp *pt_app_new (void);
-
-#endif
