@@ -1,4 +1,4 @@
-/* Copyright (C) Gabor Karsay 2019 <gabor.karsay@gmx.at>
+/* Copyright 2019 Gabor Karsay <gabor.karsay@gmx.at>
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as published
@@ -15,9 +15,13 @@
  */
 
 #include "config.h"
-#include "pt-window.h"
+
 #include "pt-controller.h"
 
+#include "pt-window-private.h"
+#include "pt-window.h"
+
+typedef struct _PtControllerPrivate PtControllerPrivate;
 struct _PtControllerPrivate
 {
   PtWindow *win;
@@ -25,47 +29,46 @@ struct _PtControllerPrivate
 
 enum
 {
-  PROP_0,
-  PROP_WIN,
+  PROP_WIN = 1,
   N_PROPERTIES
 };
 
-static GParamSpec *obj_properties[N_PROPERTIES] = {
-  NULL,
-};
+static GParamSpec *obj_properties[N_PROPERTIES];
 
-G_DEFINE_TYPE_WITH_PRIVATE (PtController, pt_controller, G_TYPE_OBJECT)
+G_DEFINE_ABSTRACT_TYPE_WITH_PRIVATE (PtController, pt_controller, G_TYPE_OBJECT)
 
 PtWindow *
 pt_controller_get_window (PtController *self)
 {
-  return self->priv->win;
+  PtControllerPrivate *priv = pt_controller_get_instance_private (self);
+  return priv->win;
 }
 
 PtPlayer *
 pt_controller_get_player (PtController *self)
 {
-  return self->priv->win->player;
+  PtControllerPrivate *priv = pt_controller_get_instance_private (self);
+  return _pt_window_get_player (priv->win);
 }
 
 static void
 pt_controller_init (PtController *self)
 {
-  self->priv = pt_controller_get_instance_private (self);
 }
 
 static void
-pt_controller_set_property (GObject *object,
-                            guint property_id,
+pt_controller_set_property (GObject      *object,
+                            guint         property_id,
                             const GValue *value,
-                            GParamSpec *pspec)
+                            GParamSpec   *pspec)
 {
-  PtController *self = PT_CONTROLLER (object);
+  PtController        *self = PT_CONTROLLER (object);
+  PtControllerPrivate *priv = pt_controller_get_instance_private (self);
 
   switch (property_id)
     {
     case PROP_WIN:
-      self->priv->win = g_value_get_object (value);
+      priv->win = g_value_get_object (value);
       break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -74,17 +77,18 @@ pt_controller_set_property (GObject *object,
 }
 
 static void
-pt_controller_get_property (GObject *object,
-                            guint property_id,
-                            GValue *value,
+pt_controller_get_property (GObject    *object,
+                            guint       property_id,
+                            GValue     *value,
                             GParamSpec *pspec)
 {
-  PtController *self = PT_CONTROLLER (object);
+  PtController        *self = PT_CONTROLLER (object);
+  PtControllerPrivate *priv = pt_controller_get_instance_private (self);
 
   switch (property_id)
     {
     case PROP_WIN:
-      g_value_set_object (value, self->priv->win);
+      g_value_set_object (value, priv->win);
       break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -100,11 +104,9 @@ pt_controller_class_init (PtControllerClass *klass)
   object_class->get_property = pt_controller_get_property;
 
   obj_properties[PROP_WIN] =
-      g_param_spec_object ("win",
-                           "Parent PtWindow",
-                           "Parent PtWindow",
+      g_param_spec_object ("win", NULL, NULL,
                            PT_WINDOW_TYPE,
-                           G_PARAM_READWRITE | G_PARAM_CONSTRUCT | G_PARAM_EXPLICIT_NOTIFY);
+                           G_PARAM_READWRITE | G_PARAM_CONSTRUCT | G_PARAM_EXPLICIT_NOTIFY | G_PARAM_STATIC_STRINGS);
 
   g_object_class_install_properties (
       object_class,
