@@ -1,4 +1,4 @@
-/* Copyright (C) Gabor Karsay 2016, 2019 <gabor.karsay@gmx.at>
+/* Copyright 2016 Gabor Karsay <gabor.karsay@gmx.at>
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as published
@@ -15,25 +15,30 @@
  */
 
 #include "config.h"
+
+#include "pt-dbus-service.h"
+
+#include "pt-window.h"
+
 #include <gio/gio.h>
 #include <glib/gi18n.h>
 #include <parlatype.h>
-#include "pt-window.h"
-#include "pt-dbus-service.h"
 
-struct _PtDbusServicePrivate
+struct _PtDbusService
 {
+  PtController parent;
+
   gint owner_id;
 };
 
-G_DEFINE_TYPE_WITH_PRIVATE (PtDbusService, pt_dbus_service, PT_CONTROLLER_TYPE)
+G_DEFINE_TYPE (PtDbusService, pt_dbus_service, PT_CONTROLLER_TYPE)
 
 static GDBusNodeInfo *introspection_data = NULL;
 
 /* Introspection data for the service we are exporting */
 static const gchar introspection_xml[] =
     "<node>"
-    "  <interface name='org.parlatype.Parlatype'>"
+    "  <interface name='xyz.parlatype.Parlatype'>"
     "    <method name='GetTimestamp'>"
     "      <arg type='s' name='timestamp' direction='out'/>"
     "    </method>"
@@ -65,14 +70,14 @@ static const gchar introspection_xml[] =
 
 static void
 player_asr_final_cb (PtPlayer *player,
-                     gchar *word,
-                     gpointer user_data)
+                     gchar    *word,
+                     gpointer  user_data)
 {
   GDBusConnection *connection = G_DBUS_CONNECTION (user_data);
   g_dbus_connection_emit_signal (connection,
                                  NULL,
-                                 "/org/parlatype/parlatype",
-                                 "org.parlatype.Parlatype",
+                                 "/xyz/parlatype/parlatype",
+                                 "xyz.parlatype.Parlatype",
                                  "ASRFinal",
                                  g_variant_new ("(s)", word),
                                  NULL);
@@ -80,31 +85,31 @@ player_asr_final_cb (PtPlayer *player,
 
 static void
 player_asr_hypothesis_cb (PtPlayer *player,
-                          gchar *word,
-                          gpointer user_data)
+                          gchar    *word,
+                          gpointer  user_data)
 {
   GDBusConnection *connection = G_DBUS_CONNECTION (user_data);
   g_dbus_connection_emit_signal (connection,
                                  NULL,
-                                 "/org/parlatype/parlatype",
-                                 "org.parlatype.Parlatype",
+                                 "/xyz/parlatype/parlatype",
+                                 "xyz.parlatype.Parlatype",
                                  "ASRHypothesis",
                                  g_variant_new ("(s)", word),
                                  NULL);
 }
 
 static void
-handle_method_call (GDBusConnection *connection,
-                    const gchar *sender,
-                    const gchar *object_path,
-                    const gchar *interface_name,
-                    const gchar *method_name,
-                    GVariant *parameters,
+handle_method_call (GDBusConnection       *connection,
+                    const gchar           *sender,
+                    const gchar           *object_path,
+                    const gchar           *interface_name,
+                    const gchar           *method_name,
+                    GVariant              *parameters,
                     GDBusMethodInvocation *invocation,
-                    gpointer user_data)
+                    gpointer               user_data)
 {
   PtDbusService *self = PT_DBUS_SERVICE (user_data);
-  PtPlayer *player = pt_controller_get_player (PT_CONTROLLER (self));
+  PtPlayer      *player = pt_controller_get_player (PT_CONTROLLER (self));
 
   gchar *timestamp = NULL;
   gchar *uri;
@@ -184,15 +189,15 @@ static const GDBusInterfaceVTable interface_vtable = {
 
 static void
 on_bus_acquired (GDBusConnection *connection,
-                 const gchar *name,
-                 gpointer user_data)
+                 const gchar     *name,
+                 gpointer         user_data)
 {
   PtDbusService *self = PT_DBUS_SERVICE (user_data);
-  PtPlayer *player = pt_controller_get_player (PT_CONTROLLER (self));
-  guint registration_id;
+  PtPlayer      *player = pt_controller_get_player (PT_CONTROLLER (self));
+  guint          registration_id;
 
   registration_id = g_dbus_connection_register_object (connection,
-                                                       "/org/parlatype/parlatype",
+                                                       "/xyz/parlatype/parlatype",
                                                        introspection_data->interfaces[0],
                                                        &interface_vtable,
                                                        user_data,
@@ -213,15 +218,15 @@ on_bus_acquired (GDBusConnection *connection,
 
 static void
 on_name_acquired (GDBusConnection *connection,
-                  const gchar *name,
-                  gpointer user_data)
+                  const gchar     *name,
+                  gpointer         user_data)
 {
 }
 
 static void
 on_name_lost (GDBusConnection *connection,
-              const gchar *name,
-              gpointer user_data)
+              const gchar     *name,
+              gpointer         user_data)
 {
 }
 
@@ -231,21 +236,20 @@ pt_dbus_service_start (PtDbusService *self)
   introspection_data = g_dbus_node_info_new_for_xml (introspection_xml, NULL);
   g_assert (introspection_data != NULL);
 
-  self->priv->owner_id = g_bus_own_name (G_BUS_TYPE_SESSION,
-                                         APP_ID,
-                                         G_BUS_NAME_OWNER_FLAGS_NONE,
-                                         on_bus_acquired,
-                                         on_name_acquired,
-                                         on_name_lost,
-                                         self,
-                                         NULL);
+  self->owner_id = g_bus_own_name (G_BUS_TYPE_SESSION,
+                                   APP_ID,
+                                   G_BUS_NAME_OWNER_FLAGS_NONE,
+                                   on_bus_acquired,
+                                   on_name_acquired,
+                                   on_name_lost,
+                                   self,
+                                   NULL);
 }
 
 static void
 pt_dbus_service_init (PtDbusService *self)
 {
-  self->priv = pt_dbus_service_get_instance_private (self);
-  self->priv->owner_id = 0;
+  self->owner_id = 0;
 }
 
 static void
@@ -253,11 +257,11 @@ pt_dbus_service_dispose (GObject *object)
 {
   PtDbusService *self = PT_DBUS_SERVICE (object);
 
-  if (self->priv->owner_id > 0)
+  if (self->owner_id > 0)
     {
-      g_bus_unown_name (self->priv->owner_id);
+      g_bus_unown_name (self->owner_id);
       g_dbus_node_info_unref (introspection_data);
-      self->priv->owner_id = 0;
+      self->owner_id = 0;
     }
 
   G_OBJECT_CLASS (pt_dbus_service_parent_class)->dispose (object);
