@@ -1,5 +1,5 @@
 /* Copyright (C) 2010  Jonathan Matthew  <jonathan@d14n.org>
- * Copyright (C) Gabor Karsay 2021 <gabor.karsay@gmx.at>
+ * Copyright 2021 Gabor Karsay <gabor.karsay@gmx.at>
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as published
@@ -18,39 +18,42 @@
  * and slightly adapted for Parlatype.
  */
 
-#include "pt-mpris.h"
 #include "config.h"
-#include "pt-window.h"
-#include <parlatype.h>
+
+#include "pt-mpris.h"
 
 #include "mpris-spec.h"
+#include "pt-window.h"
+
+#include <parlatype.h>
 
 #define ENTRY_OBJECT_PATH_PREFIX "/org/mpris/MediaPlayer2/Track/"
 
-struct _PtMprisPrivate
+struct _PtMpris
 {
+  PtController parent;
 
   GDBusConnection *connection;
-  GDBusNodeInfo *node_info;
-  guint name_own_id;
-  guint root_id;
-  guint player_id;
+  GDBusNodeInfo   *node_info;
+  guint            name_own_id;
+  guint            root_id;
+  guint            player_id;
 
   GHashTable *player_property_changes;
-  guint property_emit_id;
+  guint       property_emit_id;
 };
 
-G_DEFINE_TYPE_WITH_PRIVATE (PtMpris, pt_mpris, PT_CONTROLLER_TYPE)
+G_DEFINE_TYPE (PtMpris, pt_mpris, PT_CONTROLLER_TYPE)
 
 static void
 emit_property_changes (PtMpris *self, GHashTable *changes, const char *interface)
 {
-  GError *error = NULL;
+  GError          *error = NULL;
   GVariantBuilder *properties;
   GVariantBuilder *invalidated;
-  GVariant *parameters;
-  gpointer propname, propvalue;
-  GHashTableIter iter;
+  GVariant        *parameters;
+  gpointer         propname, propvalue;
+  GHashTableIter   iter;
 
   /* build property changes */
   properties = g_variant_builder_new (G_VARIANT_TYPE ("a{sv}"));
@@ -77,7 +80,7 @@ emit_property_changes (PtMpris *self, GHashTable *changes, const char *interface
                               invalidated);
   g_variant_builder_unref (properties);
   g_variant_builder_unref (invalidated);
-  g_dbus_connection_emit_signal (self->priv->connection,
+  g_dbus_connection_emit_signal (self->connection,
                                  NULL,
                                  MPRIS_OBJECT_NAME,
                                  "org.freedesktop.DBus.Properties",
@@ -96,43 +99,43 @@ emit_property_changes (PtMpris *self, GHashTable *changes, const char *interface
 static gboolean
 emit_properties_idle (PtMpris *self)
 {
-  if (self->priv->player_property_changes != NULL)
+  if (self->player_property_changes != NULL)
     {
-      emit_property_changes (self, self->priv->player_property_changes, MPRIS_PLAYER_INTERFACE);
-      g_hash_table_destroy (self->priv->player_property_changes);
-      self->priv->player_property_changes = NULL;
+      emit_property_changes (self, self->player_property_changes, MPRIS_PLAYER_INTERFACE);
+      g_hash_table_destroy (self->player_property_changes);
+      self->player_property_changes = NULL;
     }
 
-  self->priv->property_emit_id = 0;
+  self->property_emit_id = 0;
   return FALSE;
 }
 
 static void
-add_player_property_change (PtMpris *self,
+add_player_property_change (PtMpris    *self,
                             const char *property,
-                            GVariant *value)
+                            GVariant   *value)
 {
-  if (self->priv->player_property_changes == NULL)
+  if (self->player_property_changes == NULL)
     {
-      self->priv->player_property_changes = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, (GDestroyNotify) g_variant_unref);
+      self->player_property_changes = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, (GDestroyNotify) g_variant_unref);
     }
-  g_hash_table_insert (self->priv->player_property_changes, g_strdup (property), g_variant_ref_sink (value));
+  g_hash_table_insert (self->player_property_changes, g_strdup (property), g_variant_ref_sink (value));
 
-  if (self->priv->property_emit_id == 0)
+  if (self->property_emit_id == 0)
     {
-      self->priv->property_emit_id = g_idle_add ((GSourceFunc) emit_properties_idle, self);
+      self->property_emit_id = g_idle_add ((GSourceFunc) emit_properties_idle, self);
     }
 }
 
 static void
-handle_root_method_call (GDBusConnection *connection,
-                         const char *sender,
-                         const char *object_path,
-                         const char *interface_name,
-                         const char *method_name,
-                         GVariant *parameters,
+handle_root_method_call (GDBusConnection       *connection,
+                         const char            *sender,
+                         const char            *object_path,
+                         const char            *interface_name,
+                         const char            *method_name,
+                         GVariant              *parameters,
                          GDBusMethodInvocation *invocation,
-                         PtMpris *self)
+                         PtMpris               *self)
 {
   PtWindow *window = pt_controller_get_window (PT_CONTROLLER (self));
 
@@ -150,7 +153,7 @@ handle_root_method_call (GDBusConnection *connection,
 
   if (g_strcmp0 (method_name, "Raise") == 0)
     {
-      gtk_window_present_with_time (GTK_WINDOW (window), GDK_CURRENT_TIME);
+      gtk_window_present (GTK_WINDOW (window));
       g_dbus_method_invocation_return_value (invocation, NULL);
     }
   else if (g_strcmp0 (method_name, "Quit") == 0)
@@ -171,12 +174,12 @@ handle_root_method_call (GDBusConnection *connection,
 
 static GVariant *
 get_root_property (GDBusConnection *connection,
-                   const char *sender,
-                   const char *object_path,
-                   const char *interface_name,
-                   const char *property_name,
-                   GError **error,
-                   PtMpris *self)
+                   const char      *sender,
+                   const char      *object_path,
+                   const char      *interface_name,
+                   const char      *property_name,
+                   GError         **error,
+                   PtMpris         *self)
 {
   if (g_strcmp0 (object_path, MPRIS_OBJECT_NAME) != 0 ||
       g_strcmp0 (interface_name, MPRIS_ROOT_INTERFACE) != 0)
@@ -271,9 +274,9 @@ handle_result (GDBusMethodInvocation *invocation, gboolean ret, GError *error)
 }
 
 static void
-build_track_metadata (PtMpris *self,
+build_track_metadata (PtMpris         *self,
                       GVariantBuilder *builder,
-                      PtPlayer *player)
+                      PtPlayer        *player)
 {
   gchar *uri;
 
@@ -296,19 +299,19 @@ build_track_metadata (PtMpris *self,
 }
 
 static void
-handle_player_method_call (GDBusConnection *connection,
-                           const char *sender,
-                           const char *object_path,
-                           const char *interface_name,
-                           const char *method_name,
-                           GVariant *parameters,
+handle_player_method_call (GDBusConnection       *connection,
+                           const char            *sender,
+                           const char            *object_path,
+                           const char            *interface_name,
+                           const char            *method_name,
+                           GVariant              *parameters,
                            GDBusMethodInvocation *invocation,
-                           PtMpris *self)
+                           PtMpris               *self)
 
 {
   PtPlayer *player = pt_controller_get_player (PT_CONTROLLER (self));
-  GError *error = NULL;
-  gboolean ret;
+  GError   *error = NULL;
+  gboolean  ret;
 
   if (g_strcmp0 (object_path, MPRIS_OBJECT_NAME) != 0 ||
       g_strcmp0 (interface_name, MPRIS_PLAYER_INTERFACE) != 0)
@@ -362,7 +365,7 @@ handle_player_method_call (GDBusConnection *connection,
     }
   else if (g_strcmp0 (method_name, "SetPosition") == 0)
     {
-      gint64 position;
+      gint64      position;
       const char *trackid;
 
       g_variant_get (parameters, "(&ox)", &trackid, &position);
@@ -408,7 +411,7 @@ handle_player_method_call (GDBusConnection *connection,
 static GVariant *
 get_playback_status (PtMpris *self)
 {
-  PtPlayer *player = pt_controller_get_player (PT_CONTROLLER (self));
+  PtPlayer   *player = pt_controller_get_player (PT_CONTROLLER (self));
   PtStateType state;
 
   g_object_get (player, "state", &state, NULL);
@@ -428,14 +431,14 @@ get_playback_status (PtMpris *self)
 
 static GVariant *
 get_player_property (GDBusConnection *connection,
-                     const char *sender,
-                     const char *object_path,
-                     const char *interface_name,
-                     const char *property_name,
-                     GError **error,
-                     PtMpris *self)
+                     const char      *sender,
+                     const char      *object_path,
+                     const char      *interface_name,
+                     const char      *property_name,
+                     GError         **error,
+                     PtMpris         *self)
 {
-  PtPlayer *player = pt_controller_get_player (PT_CONTROLLER (self));
+  PtPlayer   *player = pt_controller_get_player (PT_CONTROLLER (self));
   PtStateType state;
 
   if (g_strcmp0 (object_path, MPRIS_OBJECT_NAME) != 0 ||
@@ -461,7 +464,7 @@ get_player_property (GDBusConnection *connection,
   else if (g_strcmp0 (property_name, "Metadata") == 0)
     {
       GVariantBuilder *builder;
-      GVariant *v;
+      GVariant        *v;
 
       builder = g_variant_builder_new (G_VARIANT_TYPE ("a{sv}"));
       build_track_metadata (self, builder, player);
@@ -548,13 +551,13 @@ get_player_property (GDBusConnection *connection,
 
 static gboolean
 set_player_property (GDBusConnection *connection,
-                     const char *sender,
-                     const char *object_path,
-                     const char *interface_name,
-                     const char *property_name,
-                     GVariant *value,
-                     GError **error,
-                     PtMpris *self)
+                     const char      *sender,
+                     const char      *object_path,
+                     const char      *interface_name,
+                     const char      *property_name,
+                     GVariant        *value,
+                     GError         **error,
+                     PtMpris         *self)
 {
   PtPlayer *player = pt_controller_get_player (PT_CONTROLLER (self));
 
@@ -599,7 +602,7 @@ static const GDBusInterfaceVTable player_vtable = {
 static void
 state_changed_cb (GObject *object, GParamSpec *pspec, PtMpris *self)
 {
-  PtPlayer *player = pt_controller_get_player (PT_CONTROLLER (self));
+  PtPlayer   *player = pt_controller_get_player (PT_CONTROLLER (self));
   PtStateType state;
 
   g_object_get (player, "state", &state, NULL);
@@ -630,7 +633,7 @@ volume_changed_cb (GObject *object, GParamSpec *pspec, PtMpris *self)
 static void
 uri_changed_cb (GObject *object, GParamSpec *pspec, PtMpris *self)
 {
-  PtPlayer *player = pt_controller_get_player (PT_CONTROLLER (self));
+  PtPlayer        *player = pt_controller_get_player (PT_CONTROLLER (self));
   GVariantBuilder *builder;
 
   builder = g_variant_builder_new (G_VARIANT_TYPE ("a{sv}"));
@@ -657,11 +660,11 @@ name_lost_cb (GDBusConnection *connection, const char *name, PtMpris *self)
 void
 pt_mpris_start (PtMpris *self)
 {
-  PtPlayer *player = pt_controller_get_player (PT_CONTROLLER (self));
+  PtPlayer           *player = pt_controller_get_player (PT_CONTROLLER (self));
   GDBusInterfaceInfo *ifaceinfo;
-  GError *error = NULL;
+  GError             *error = NULL;
 
-  self->priv->connection = g_bus_get_sync (G_BUS_TYPE_SESSION, NULL, &error);
+  self->connection = g_bus_get_sync (G_BUS_TYPE_SESSION, NULL, &error);
   if (error != NULL)
     {
       g_log_structured (G_LOG_DOMAIN, G_LOG_LEVEL_WARNING,
@@ -670,7 +673,7 @@ pt_mpris_start (PtMpris *self)
     }
 
   /* parse introspection data */
-  self->priv->node_info = g_dbus_node_info_new_for_xml (mpris_introspection_xml, &error);
+  self->node_info = g_dbus_node_info_new_for_xml (mpris_introspection_xml, &error);
   if (error != NULL)
     {
       g_log_structured (G_LOG_DOMAIN, G_LOG_LEVEL_WARNING,
@@ -679,14 +682,14 @@ pt_mpris_start (PtMpris *self)
     }
 
   /* register root interface */
-  ifaceinfo = g_dbus_node_info_lookup_interface (self->priv->node_info, MPRIS_ROOT_INTERFACE);
-  self->priv->root_id = g_dbus_connection_register_object (self->priv->connection,
-                                                           MPRIS_OBJECT_NAME,
-                                                           ifaceinfo,
-                                                           &root_vtable,
-                                                           self,
-                                                           NULL,
-                                                           &error);
+  ifaceinfo = g_dbus_node_info_lookup_interface (self->node_info, MPRIS_ROOT_INTERFACE);
+  self->root_id = g_dbus_connection_register_object (self->connection,
+                                                     MPRIS_OBJECT_NAME,
+                                                     ifaceinfo,
+                                                     &root_vtable,
+                                                     self,
+                                                     NULL,
+                                                     &error);
   if (error != NULL)
     {
       g_log_structured (G_LOG_DOMAIN, G_LOG_LEVEL_WARNING,
@@ -695,14 +698,14 @@ pt_mpris_start (PtMpris *self)
     }
 
   /* register player interface */
-  ifaceinfo = g_dbus_node_info_lookup_interface (self->priv->node_info, MPRIS_PLAYER_INTERFACE);
-  self->priv->player_id = g_dbus_connection_register_object (self->priv->connection,
-                                                             MPRIS_OBJECT_NAME,
-                                                             ifaceinfo,
-                                                             &player_vtable,
-                                                             self,
-                                                             NULL,
-                                                             &error);
+  ifaceinfo = g_dbus_node_info_lookup_interface (self->node_info, MPRIS_PLAYER_INTERFACE);
+  self->player_id = g_dbus_connection_register_object (self->connection,
+                                                       MPRIS_OBJECT_NAME,
+                                                       ifaceinfo,
+                                                       &player_vtable,
+                                                       self,
+                                                       NULL,
+                                                       &error);
   if (error != NULL)
     {
       g_log_structured (G_LOG_DOMAIN, G_LOG_LEVEL_WARNING,
@@ -730,37 +733,36 @@ pt_mpris_start (PtMpris *self)
                            G_CALLBACK (uri_changed_cb),
                            self, 0);
 
-  self->priv->name_own_id = g_bus_own_name (G_BUS_TYPE_SESSION,
-                                            MPRIS_BUS_NAME_PREFIX ".parlatype",
-                                            G_BUS_NAME_OWNER_FLAGS_NONE,
-                                            NULL,
-                                            (GBusNameAcquiredCallback) name_acquired_cb,
-                                            (GBusNameLostCallback) name_lost_cb,
-                                            g_object_ref (self),
-                                            g_object_unref);
+  self->name_own_id = g_bus_own_name (G_BUS_TYPE_SESSION,
+                                      MPRIS_BUS_NAME_PREFIX ".parlatype",
+                                      G_BUS_NAME_OWNER_FLAGS_NONE,
+                                      NULL,
+                                      (GBusNameAcquiredCallback) name_acquired_cb,
+                                      (GBusNameLostCallback) name_lost_cb,
+                                      g_object_ref (self),
+                                      g_object_unref);
 }
 
 static void
 pt_mpris_init (PtMpris *self)
 {
-  self->priv = pt_mpris_get_instance_private (self);
 }
 
 static void
 pt_mpris_dispose (GObject *object)
 {
-  PtMpris *self = PT_MPRIS (object);
+  PtMpris  *self = PT_MPRIS (object);
   PtPlayer *player = pt_controller_get_player (PT_CONTROLLER (self));
 
-  if (self->priv->root_id != 0)
+  if (self->root_id != 0)
     {
-      g_dbus_connection_unregister_object (self->priv->connection, self->priv->root_id);
-      self->priv->root_id = 0;
+      g_dbus_connection_unregister_object (self->connection, self->root_id);
+      self->root_id = 0;
     }
-  if (self->priv->player_id != 0)
+  if (self->player_id != 0)
     {
-      g_dbus_connection_unregister_object (self->priv->connection, self->priv->player_id);
-      self->priv->player_id = 0;
+      g_dbus_connection_unregister_object (self->connection, self->player_id);
+      self->player_id = 0;
     }
 
   g_signal_handlers_disconnect_by_func (player,
