@@ -1,4 +1,4 @@
-/* Copyright (C) Gabor Karsay 2021 <gabor.karsay@gmx.at>
+/* Copyright 2021 Gabor Karsay <gabor.karsay@gmx.at>
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as published
@@ -14,38 +14,13 @@
  * with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef PT_MPRIS_H
-#define PT_MPRIS_H
+#pragma once
 
-#include "config.h"
 #include "pt-controller.h"
-#include "pt-window.h"
 
 #define PT_MPRIS_TYPE (pt_mpris_get_type ())
-#define PT_MPRIS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PT_MPRIS_TYPE, PtMpris))
-#define PT_IS_MPRIS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PT_MPRIS_TYPE))
+G_DECLARE_FINAL_TYPE (PtMpris, pt_mpris, PT, MPRIS, PtController)
 
-typedef struct _PtMpris PtMpris;
-typedef struct _PtMprisClass PtMprisClass;
-typedef struct _PtMprisPrivate PtMprisPrivate;
+void     pt_mpris_start (PtMpris  *self);
 
-struct _PtMpris
-{
-  PtController parent;
-
-  /*< private > */
-  PtMprisPrivate *priv;
-};
-
-struct _PtMprisClass
-{
-  PtControllerClass parent_class;
-};
-
-GType pt_mpris_get_type (void) G_GNUC_CONST;
-
-void pt_mpris_start (PtMpris *self);
-
-PtMpris *pt_mpris_new (PtWindow *win);
-
-#endif
+PtMpris *pt_mpris_new   (PtWindow *win);
