@@ -1,4 +1,4 @@
-/* Copyright (C) Gabor Karsay 2016 <gabor.karsay@gmx.at>
+/* Copyright 2016 Gabor Karsay <gabor.karsay@gmx.at>
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as published
@@ -14,12 +14,8 @@
  * with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef PT_WINDOW_DND_H
-#define PT_WINDOW_DND_H
+#pragma once
 
-#include "config.h"
 #include "pt-window.h"
 
-void pt_window_setup_dnd (PtWindow *win);
-
-#endif
+void pt_window_setup_dnd (PtWindow *self);
